# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from enum import Enum


class TimeZone(Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    allowed enum values
    """

    MOROCCOSTANDARDTIME = "MOROCCOSTANDARDTIME"
    UTC = "UTC"
    GMTSTANDARDTIME = "GMTSTANDARDTIME"
    GREENWICHSTANDARDTIME = "GREENWICHSTANDARDTIME"
    WEUROPESTANDARDTIME = "WEUROPESTANDARDTIME"
    CENTRALEUROPESTANDARDTIME = "CENTRALEUROPESTANDARDTIME"
    ROMANCESTANDARDTIME = "ROMANCESTANDARDTIME"
    CENTRALEUROPEANSTANDARDTIME = "CENTRALEUROPEANSTANDARDTIME"
    WCENTRALAFRICASTANDARDTIME = "WCENTRALAFRICASTANDARDTIME"
    NAMIBIASTANDARDTIME = "NAMIBIASTANDARDTIME"
    JORDANSTANDARDTIME = "JORDANSTANDARDTIME"
    GTBSTANDARDTIME = "GTBSTANDARDTIME"
    MIDDLEEASTSTANDARDTIME = "MIDDLEEASTSTANDARDTIME"
    EGYPTSTANDARDTIME = "EGYPTSTANDARDTIME"
    SYRIASTANDARDTIME = "SYRIASTANDARDTIME"
    EEUROPESTANDARDTIME = "EEUROPESTANDARDTIME"
    SOUTHAFRICASTANDARDTIME = "SOUTHAFRICASTANDARDTIME"
    FLESTANDARDTIME = "FLESTANDARDTIME"
    TURKEYSTANDARDTIME = "TURKEYSTANDARDTIME"
    ISRAELSTANDARDTIME = "ISRAELSTANDARDTIME"
    KALININGRADSTANDARDTIME = "KALININGRADSTANDARDTIME"
    LIBYASTANDARDTIME = "LIBYASTANDARDTIME"
    ARABICSTANDARDTIME = "ARABICSTANDARDTIME"
    ARABSTANDARDTIME = "ARABSTANDARDTIME"
    BELARUSSTANDARDTIME = "BELARUSSTANDARDTIME"
    RUSSIANSTANDARDTIME = "RUSSIANSTANDARDTIME"
    EAFRICASTANDARDTIME = "EAFRICASTANDARDTIME"
    IRANSTANDARDTIME = "IRANSTANDARDTIME"
    ARABIANSTANDARDTIME = "ARABIANSTANDARDTIME"
    AZERBAIJANSTANDARDTIME = "AZERBAIJANSTANDARDTIME"
    RUSSIATIMEZONE3 = "RUSSIATIMEZONE3"
    MAURITIUSSTANDARDTIME = "MAURITIUSSTANDARDTIME"
    GEORGIANSTANDARDTIME = "GEORGIANSTANDARDTIME"
    CAUCASUSSTANDARDTIME = "CAUCASUSSTANDARDTIME"
    AFGHANISTANSTANDARDTIME = "AFGHANISTANSTANDARDTIME"
    WESTASIASTANDARDTIME = "WESTASIASTANDARDTIME"
    EKATERINBURGSTANDARDTIME = "EKATERINBURGSTANDARDTIME"
    PAKISTANSTANDARDTIME = "PAKISTANSTANDARDTIME"
    INDIASTANDARDTIME = "INDIASTANDARDTIME"
    SRILANKASTANDARDTIME = "SRILANKASTANDARDTIME"
    NEPALSTANDARDTIME = "NEPALSTANDARDTIME"
    CENTRALASIASTANDARDTIME = "CENTRALASIASTANDARDTIME"
    BANGLADESHSTANDARDTIME = "BANGLADESHSTANDARDTIME"
    NCENTRALASIASTANDARDTIME = "NCENTRALASIASTANDARDTIME"
    MYANMARSTANDARDTIME = "MYANMARSTANDARDTIME"
    SEASIASTANDARDTIME = "SEASIASTANDARDTIME"
    NORTHASIASTANDARDTIME = "NORTHASIASTANDARDTIME"
    CHINASTANDARDTIME = "CHINASTANDARDTIME"
    NORTHASIAEASTSTANDARDTIME = "NORTHASIAEASTSTANDARDTIME"
    SINGAPORESTANDARDTIME = "SINGAPORESTANDARDTIME"
    WAUSTRALIASTANDARDTIME = "WAUSTRALIASTANDARDTIME"
    TAIPEISTANDARDTIME = "TAIPEISTANDARDTIME"
    ULAANBAATARSTANDARDTIME = "ULAANBAATARSTANDARDTIME"
    TOKYOSTANDARDTIME = "TOKYOSTANDARDTIME"
    KOREASTANDARDTIME = "KOREASTANDARDTIME"
    YAKUTSKSTANDARDTIME = "YAKUTSKSTANDARDTIME"
    CENAUSTRALIASTANDARDTIME = "CENAUSTRALIASTANDARDTIME"
    AUSCENTRALSTANDARDTIME = "AUSCENTRALSTANDARDTIME"
    EAUSTRALIASTANDARDTIME = "EAUSTRALIASTANDARDTIME"
    AUSEASTERNSTANDARDTIME = "AUSEASTERNSTANDARDTIME"
    WESTPACIFICSTANDARDTIME = "WESTPACIFICSTANDARDTIME"
    TASMANIASTANDARDTIME = "TASMANIASTANDARDTIME"
    MAGADANSTANDARDTIME = "MAGADANSTANDARDTIME"
    VLADIVOSTOKSTANDARDTIME = "VLADIVOSTOKSTANDARDTIME"
    RUSSIATIMEZONE10 = "RUSSIATIMEZONE10"
    CENTRALPACIFICSTANDARDTIME = "CENTRALPACIFICSTANDARDTIME"
    RUSSIATIMEZONE11 = "RUSSIATIMEZONE11"
    NEWZEALANDSTANDARDTIME = "NEWZEALANDSTANDARDTIME"
    UTC_12 = "UTC+12"
    UTC_13 = "UTC+13"
    FIJISTANDARDTIME = "FIJISTANDARDTIME"
    KAMCHATKASTANDARDTIME = "KAMCHATKASTANDARDTIME"
    TONGASTANDARDTIME = "TONGASTANDARDTIME"
    SAMOASTANDARDTIME = "SAMOASTANDARDTIME"
    LINEISLANDSSTANDARDTIME = "LINEISLANDSSTANDARDTIME"
    AZORESSTANDARDTIME = "AZORESSTANDARDTIME"
    CAPEVERDESTANDARDTIME = "CAPEVERDESTANDARDTIME"
    UTC02 = "UTC02"
    MIDATLANTICSTANDARDTIME = "MIDATLANTICSTANDARDTIME"
    ESOUTHAMERICASTANDARDTIME = "ESOUTHAMERICASTANDARDTIME"
    ARGENTINASTANDARDTIME = "ARGENTINASTANDARDTIME"
    SAEASTERNSTANDARDTIME = "SAEASTERNSTANDARDTIME"
    GREENLANDSTANDARDTIME = "GREENLANDSTANDARDTIME"
    MONTEVIDEOSTANDARDTIME = "MONTEVIDEOSTANDARDTIME"
    BAHIASTANDARDTIME = "BAHIASTANDARDTIME"
    NEWFOUNDLANDSTANDARDTIME = "NEWFOUNDLANDSTANDARDTIME"
    PARAGUAYSTANDARDTIME = "PARAGUAYSTANDARDTIME"
    ATLANTICSTANDARDTIME = "ATLANTICSTANDARDTIME"
    CENTRALBRAZILIANSTANDARDTIME = "CENTRALBRAZILIANSTANDARDTIME"
    SAWESTERNSTANDARDTIME = "SAWESTERNSTANDARDTIME"
    PACIFICSASTANDARDTIME = "PACIFICSASTANDARDTIME"
    VENEZUELASTANDARDTIME = "VENEZUELASTANDARDTIME"
    SAPACIFICSTANDARDTIME = "SAPACIFICSTANDARDTIME"
    EASTERNSTANDARDTIME = "EASTERNSTANDARDTIME"
    USEASTERNSTANDARDTIME = "USEASTERNSTANDARDTIME"
    CENTRALAMERICASTANDARDTIME = "CENTRALAMERICASTANDARDTIME"
    CENTRALSTANDARDTIME = "CENTRALSTANDARDTIME"
    CENTRALSTANDARDTIME_MEXICO_ = "CENTRALSTANDARDTIME(MEXICO)"
    CANADACENTRALSTANDARDTIME = "CANADACENTRALSTANDARDTIME"
    USMOUNTAINSTANDARDTIME = "USMOUNTAINSTANDARDTIME"
    MOUNTAINSTANDARDTIME_MEXICO_ = "MOUNTAINSTANDARDTIME(MEXICO)"
    MOUNTAINSTANDARDTIME = "MOUNTAINSTANDARDTIME"
    PACIFICSTANDARDTIME_MEXICO_ = "PACIFICSTANDARDTIME(MEXICO)"
    PACIFICSTANDARDTIME = "PACIFICSTANDARDTIME"
    ALASKANSTANDARDTIME = "ALASKANSTANDARDTIME"
    HAWAIIANSTANDARDTIME = "HAWAIIANSTANDARDTIME"
    UTC11 = "UTC11"
    DATELINESTANDARDTIME = "DATELINESTANDARDTIME"



# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from enum import Enum


class TaxCode(Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    allowed enum values
    """

    ND = "ND"
    M = "M"
    ME = "ME"
    MSL = "MSL"
    MESL = "MESL"
    SB = "SB"
    S = "S"
    SH = "SH"
    ST = "ST"
    SBSL = "SBSL"
    SSL = "SSL"
    SHSL = "SHSL"
    STSL = "STSL"
    WT = "WT"
    CAE = "CAE"
    EDW = "EDW"
    NSW = "NSW"
    STC = "STC"
    STCSL = "STCSL"



# coding: utf-8

# flake8: noqa
"""
    Xero Projects API

    This is the Xero Projects API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


# import models into model package
from xero_python.project.models.amount import Amount
from xero_python.project.models.charge_type import ChargeType
from xero_python.project.models.currency_code import CurrencyCode
from xero_python.project.models.error import Error
from xero_python.project.models.pagination import Pagination
from xero_python.project.models.project import Project
from xero_python.project.models.project_create_or_update import ProjectCreateOrUpdate
from xero_python.project.models.project_patch import ProjectPatch
from xero_python.project.models.project_status import ProjectStatus
from xero_python.project.models.project_user import ProjectUser
from xero_python.project.models.project_users import ProjectUsers
from xero_python.project.models.projects import Projects
from xero_python.project.models.task import Task
from xero_python.project.models.task_create_or_update import TaskCreateOrUpdate
from xero_python.project.models.tasks import Tasks
from xero_python.project.models.time_entries import TimeEntries
from xero_python.project.models.time_entry import TimeEntry
from xero_python.project.models.time_entry_create_or_update import (
    TimeEntryCreateOrUpdate,
)



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class TimesheetEarningsLine(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "earnings_rate_id": "str",
        "rate_per_unit": "float",
        "number_of_units": "float",
        "fixed_amount": "float",
        "amount": "float",
        "is_linked_to_timesheet": "bool",
    }

    attribute_map = {
        "earnings_rate_id": "earningsRateID",
        "rate_per_unit": "ratePerUnit",
        "number_of_units": "numberOfUnits",
        "fixed_amount": "fixedAmount",
        "amount": "amount",
        "is_linked_to_timesheet": "isLinkedToTimesheet",
    }

    def __init__(
        self,
        earnings_rate_id=None,
        rate_per_unit=None,
        number_of_units=None,
        fixed_amount=None,
        amount=None,
        is_linked_to_timesheet=None,
    ):  # noqa: E501
        """TimesheetEarningsLine - a model defined in OpenAPI"""  # noqa: E501

        self._earnings_rate_id = None
        self._rate_per_unit = None
        self._number_of_units = None
        self._fixed_amount = None
        self._amount = None
        self._is_linked_to_timesheet = None
        self.discriminator = None

        if earnings_rate_id is not None:
            self.earnings_rate_id = earnings_rate_id
        if rate_per_unit is not None:
            self.rate_per_unit = rate_per_unit
        if number_of_units is not None:
            self.number_of_units = number_of_units
        if fixed_amount is not None:
            self.fixed_amount = fixed_amount
        if amount is not None:
            self.amount = amount
        if is_linked_to_timesheet is not None:
            self.is_linked_to_timesheet = is_linked_to_timesheet

    @property
    def earnings_rate_id(self):
        """Gets the earnings_rate_id of this TimesheetEarningsLine.  # noqa: E501

        Xero identifier for payroll timesheet earnings rate  # noqa: E501

        :return: The earnings_rate_id of this TimesheetEarningsLine.  # noqa: E501
        :rtype: str
        """
        return self._earnings_rate_id

    @earnings_rate_id.setter
    def earnings_rate_id(self, earnings_rate_id):
        """Sets the earnings_rate_id of this TimesheetEarningsLine.

        Xero identifier for payroll timesheet earnings rate  # noqa: E501

        :param earnings_rate_id: The earnings_rate_id of this TimesheetEarningsLine.  # noqa: E501
        :type: str
        """

        self._earnings_rate_id = earnings_rate_id

    @property
    def rate_per_unit(self):
        """Gets the rate_per_unit of this TimesheetEarningsLine.  # noqa: E501

        Rate per unit for timesheet earnings line  # noqa: E501

        :return: The rate_per_unit of this TimesheetEarningsLine.  # noqa: E501
        :rtype: float
        """
        return self._rate_per_unit

    @rate_per_unit.setter
    def rate_per_unit(self, rate_per_unit):
        """Sets the rate_per_unit of this TimesheetEarningsLine.

        Rate per unit for timesheet earnings line  # noqa: E501

        :param rate_per_unit: The rate_per_unit of this TimesheetEarningsLine.  # noqa: E501
        :type: float
        """

        self._rate_per_unit = rate_per_unit

    @property
    def number_of_units(self):
        """Gets the number_of_units of this TimesheetEarningsLine.  # noqa: E501

        Timesheet earnings number of units  # noqa: E501

        :return: The number_of_units of this TimesheetEarningsLine.  # noqa: E501
        :rtype: float
        """
        return self._number_of_units

    @number_of_units.setter
    def number_of_units(self, number_of_units):
        """Sets the number_of_units of this TimesheetEarningsLine.

        Timesheet earnings number of units  # noqa: E501

        :param number_of_units: The number_of_units of this TimesheetEarningsLine.  # noqa: E501
        :type: float
        """

        self._number_of_units = number_of_units

    @property
    def fixed_amount(self):
        """Gets the fixed_amount of this TimesheetEarningsLine.  # noqa: E501

        Timesheet earnings fixed amount. Only applicable if the EarningsRate RateType is Fixed  # noqa: E501

        :return: The fixed_amount of this TimesheetEarningsLine.  # noqa: E501
        :rtype: float
        """
        return self._fixed_amount

    @fixed_amount.setter
    def fixed_amount(self, fixed_amount):
        """Sets the fixed_amount of this TimesheetEarningsLine.

        Timesheet earnings fixed amount. Only applicable if the EarningsRate RateType is Fixed  # noqa: E501

        :param fixed_amount: The fixed_amount of this TimesheetEarningsLine.  # noqa: E501
        :type: float
        """

        self._fixed_amount = fixed_amount

    @property
    def amount(self):
        """Gets the amount of this TimesheetEarningsLine.  # noqa: E501

        The amount of the timesheet earnings line.  # noqa: E501

        :return: The amount of this TimesheetEarningsLine.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this TimesheetEarningsLine.

        The amount of the timesheet earnings line.  # noqa: E501

        :param amount: The amount of this TimesheetEarningsLine.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def is_linked_to_timesheet(self):
        """Gets the is_linked_to_timesheet of this TimesheetEarningsLine.  # noqa: E501

        Identifies if the timesheet earnings is taken from the timesheet. False for leave earnings line  # noqa: E501

        :return: The is_linked_to_timesheet of this TimesheetEarningsLine.  # noqa: E501
        :rtype: bool
        """
        return self._is_linked_to_timesheet

    @is_linked_to_timesheet.setter
    def is_linked_to_timesheet(self, is_linked_to_timesheet):
        """Sets the is_linked_to_timesheet of this TimesheetEarningsLine.

        Identifies if the timesheet earnings is taken from the timesheet. False for leave earnings line  # noqa: E501

        :param is_linked_to_timesheet: The is_linked_to_timesheet of this TimesheetEarningsLine.  # noqa: E501
        :type: bool
        """

        self._is_linked_to_timesheet = is_linked_to_timesheet



# coding: utf-8

"""
    Xero Files API

    These endpoints are specific to Xero Files API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from enum import Enum


class ObjectType(Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    allowed enum values
    """

    UNKNOWN = "Unknown"
    ACCPAY = "Accpay"
    ACCPAYCREDIT = "AccPayCredit"
    ACCPAYPAYMENT = "AccPayPayment"
    ACCREC = "AccRec"
    ACCRECCREDIT = "AccRecCredit"
    ACCRECPAYMENT = "AccRecPayment"
    ADJUSTMENT = "Adjustment"
    APCREDITPAYMENT = "ApCreditPayment"
    APOVERPAYMENT = "ApOverPayment"
    APOVERPAYMENTPAYMENT = "ApOverPaymentPayment"
    APOVERPAYMENTSOURCEPAYMENT = "ApOverPaymentSourcePayment"
    APPREPAYMENT = "ApPrepayment"
    APPREPAYMENTPAYMENT = "ApPrepaymentPayment"
    APPREPAYMENTSOURCEPAYMENT = "ApPrepaymentSourcePayment"
    ARCREDITPAYMENT = "ArCreditPayment"
    AROVERPAYMENT = "ArOverPayment"
    AROVERPAYMENTPAYMENT = "ArOverpaymentPayment"
    AROVERPAYMENTSOURCEPAYMENT = "ArOverpaymentSourcePayment"
    ARPREPAYMENT = "ArPrepayment"
    ARPREPAYMENTPAYMENT = "ArPrepaymentPayment"
    ARPREPAYMENTSOURCEPAYMENT = "ArPrepaymentSourcePayment"
    CASHPAID = "CashPaid"
    CASHREC = "CashRec"
    EXPPAYMENT = "ExpPayment"
    MANJOURNAL = "ManJournal"
    PURCHASEORDER = "PurchaseOrder"
    RECEIPT = "Receipt"
    TRANSFER = "Transfer"
    ACCOUNT = "Account"
    CONTACT = "Contact"
    BUSINESS = "Business"
    EMPLOYEE = "Employee"
    PERSON = "Person"
    USER = "User"
    ORG = "Org"
    FIXEDASSET = "FixedAsset"
    PAYRUN = "PayRun"
    PRICELISTITEM = "PriceListItem"
    BANK = "Bank"
    CURRENT = "Current"
    EQUITY = "Equity"
    EXPENSE = "Expense"
    FIXED = "Fixed"
    LIABILITY = "Liability"
    PREPAYMENT = "Prepayment"
    REVENUE = "Revenue"
    SALES = "Sales"
    OVERHEADS = "Overheads"
    DEPRECIATN = "Depreciatn"
    OTHERINCOME = "OtherIncome"
    DIRECTCOSTS = "DirectCosts"
    CURRLIAB = "Currliab"
    TERMLIAB = "Termliab"
    NONCURRENT = "NonCurrent"



# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class SalaryAndWage(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "salary_and_wages_id": "str",
        "earnings_rate_id": "str",
        "number_of_units_per_week": "float",
        "rate_per_unit": "float",
        "number_of_units_per_day": "float",
        "days_per_week": "float",
        "effective_from": "date",
        "annual_salary": "float",
        "status": "str",
        "payment_type": "str",
    }

    attribute_map = {
        "salary_and_wages_id": "salaryAndWagesID",
        "earnings_rate_id": "earningsRateID",
        "number_of_units_per_week": "numberOfUnitsPerWeek",
        "rate_per_unit": "ratePerUnit",
        "number_of_units_per_day": "numberOfUnitsPerDay",
        "days_per_week": "daysPerWeek",
        "effective_from": "effectiveFrom",
        "annual_salary": "annualSalary",
        "status": "status",
        "payment_type": "paymentType",
    }

    def __init__(
        self,
        salary_and_wages_id=None,
        earnings_rate_id=None,
        number_of_units_per_week=None,
        rate_per_unit=None,
        number_of_units_per_day=None,
        days_per_week=None,
        effective_from=None,
        annual_salary=None,
        status=None,
        payment_type=None,
    ):  # noqa: E501
        """SalaryAndWage - a model defined in OpenAPI"""  # noqa: E501

        self._salary_and_wages_id = None
        self._earnings_rate_id = None
        self._number_of_units_per_week = None
        self._rate_per_unit = None
        self._number_of_units_per_day = None
        self._days_per_week = None
        self._effective_from = None
        self._annual_salary = None
        self._status = None
        self._payment_type = None
        self.discriminator = None

        if salary_and_wages_id is not None:
            self.salary_and_wages_id = salary_and_wages_id
        self.earnings_rate_id = earnings_rate_id
        self.number_of_units_per_week = number_of_units_per_week
        if rate_per_unit is not None:
            self.rate_per_unit = rate_per_unit
        self.number_of_units_per_day = number_of_units_per_day
        if days_per_week is not None:
            self.days_per_week = days_per_week
        self.effective_from = effective_from
        self.annual_salary = annual_salary
        self.status = status
        self.payment_type = payment_type

    @property
    def salary_and_wages_id(self):
        """Gets the salary_and_wages_id of this SalaryAndWage.  # noqa: E501

        Xero unique identifier for a salary and wages record  # noqa: E501

        :return: The salary_and_wages_id of this SalaryAndWage.  # noqa: E501
        :rtype: str
        """
        return self._salary_and_wages_id

    @salary_and_wages_id.setter
    def salary_and_wages_id(self, salary_and_wages_id):
        """Sets the salary_and_wages_id of this SalaryAndWage.

        Xero unique identifier for a salary and wages record  # noqa: E501

        :param salary_and_wages_id: The salary_and_wages_id of this SalaryAndWage.  # noqa: E501
        :type: str
        """

        self._salary_and_wages_id = salary_and_wages_id

    @property
    def earnings_rate_id(self):
        """Gets the earnings_rate_id of this SalaryAndWage.  # noqa: E501

        Xero unique identifier for an earnings rate  # noqa: E501

        :return: The earnings_rate_id of this SalaryAndWage.  # noqa: E501
        :rtype: str
        """
        return self._earnings_rate_id

    @earnings_rate_id.setter
    def earnings_rate_id(self, earnings_rate_id):
        """Sets the earnings_rate_id of this SalaryAndWage.

        Xero unique identifier for an earnings rate  # noqa: E501

        :param earnings_rate_id: The earnings_rate_id of this SalaryAndWage.  # noqa: E501
        :type: str
        """
        if earnings_rate_id is None:
            raise ValueError(
                "Invalid value for `earnings_rate_id`, must not be `None`"
            )  # noqa: E501

        self._earnings_rate_id = earnings_rate_id

    @property
    def number_of_units_per_week(self):
        """Gets the number_of_units_per_week of this SalaryAndWage.  # noqa: E501

        The Number of Units per week for the corresponding salary and wages  # noqa: E501

        :return: The number_of_units_per_week of this SalaryAndWage.  # noqa: E501
        :rtype: float
        """
        return self._number_of_units_per_week

    @number_of_units_per_week.setter
    def number_of_units_per_week(self, number_of_units_per_week):
        """Sets the number_of_units_per_week of this SalaryAndWage.

        The Number of Units per week for the corresponding salary and wages  # noqa: E501

        :param number_of_units_per_week: The number_of_units_per_week of this SalaryAndWage.  # noqa: E501
        :type: float
        """
        if number_of_units_per_week is None:
            raise ValueError(
                "Invalid value for `number_of_units_per_week`, must not be `None`"
            )  # noqa: E501

        self._number_of_units_per_week = number_of_units_per_week

    @property
    def rate_per_unit(self):
        """Gets the rate_per_unit of this SalaryAndWage.  # noqa: E501

        The rate of each unit for the corresponding salary and wages  # noqa: E501

        :return: The rate_per_unit of this SalaryAndWage.  # noqa: E501
        :rtype: float
        """
        return self._rate_per_unit

    @rate_per_unit.setter
    def rate_per_unit(self, rate_per_unit):
        """Sets the rate_per_unit of this SalaryAndWage.

        The rate of each unit for the corresponding salary and wages  # noqa: E501

        :param rate_per_unit: The rate_per_unit of this SalaryAndWage.  # noqa: E501
        :type: float
        """

        self._rate_per_unit = rate_per_unit

    @property
    def number_of_units_per_day(self):
        """Gets the number_of_units_per_day of this SalaryAndWage.  # noqa: E501

        The Number of Units per day for the corresponding salary and wages  # noqa: E501

        :return: The number_of_units_per_day of this SalaryAndWage.  # noqa: E501
        :rtype: float
        """
        return self._number_of_units_per_day

    @number_of_units_per_day.setter
    def number_of_units_per_day(self, number_of_units_per_day):
        """Sets the number_of_units_per_day of this SalaryAndWage.

        The Number of Units per day for the corresponding salary and wages  # noqa: E501

        :param number_of_units_per_day: The number_of_units_per_day of this SalaryAndWage.  # noqa: E501
        :type: float
        """
        if number_of_units_per_day is None:
            raise ValueError(
                "Invalid value for `number_of_units_per_day`, must not be `None`"
            )  # noqa: E501

        self._number_of_units_per_day = number_of_units_per_day

    @property
    def days_per_week(self):
        """Gets the days_per_week of this SalaryAndWage.  # noqa: E501

        The days per week for the salary.  # noqa: E501

        :return: The days_per_week of this SalaryAndWage.  # noqa: E501
        :rtype: float
        """
        return self._days_per_week

    @days_per_week.setter
    def days_per_week(self, days_per_week):
        """Sets the days_per_week of this SalaryAndWage.

        The days per week for the salary.  # noqa: E501

        :param days_per_week: The days_per_week of this SalaryAndWage.  # noqa: E501
        :type: float
        """

        self._days_per_week = days_per_week

    @property
    def effective_from(self):
        """Gets the effective_from of this SalaryAndWage.  # noqa: E501

        The effective date of the corresponding salary and wages  # noqa: E501

        :return: The effective_from of this SalaryAndWage.  # noqa: E501
        :rtype: date
        """
        return self._effective_from

    @effective_from.setter
    def effective_from(self, effective_from):
        """Sets the effective_from of this SalaryAndWage.

        The effective date of the corresponding salary and wages  # noqa: E501

        :param effective_from: The effective_from of this SalaryAndWage.  # noqa: E501
        :type: date
        """
        if effective_from is None:
            raise ValueError(
                "Invalid value for `effective_from`, must not be `None`"
            )  # noqa: E501

        self._effective_from = effective_from

    @property
    def annual_salary(self):
        """Gets the annual_salary of this SalaryAndWage.  # noqa: E501

        The annual salary  # noqa: E501

        :return: The annual_salary of this SalaryAndWage.  # noqa: E501
        :rtype: float
        """
        return self._annual_salary

    @annual_salary.setter
    def annual_salary(self, annual_salary):
        """Sets the annual_salary of this SalaryAndWage.

        The annual salary  # noqa: E501

        :param annual_salary: The annual_salary of this SalaryAndWage.  # noqa: E501
        :type: float
        """
        if annual_salary is None:
            raise ValueError(
                "Invalid value for `annual_salary`, must not be `None`"
            )  # noqa: E501

        self._annual_salary = annual_salary

    @property
    def status(self):
        """Gets the status of this SalaryAndWage.  # noqa: E501

        The current status of the corresponding salary and wages  # noqa: E501

        :return: The status of this SalaryAndWage.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SalaryAndWage.

        The current status of the corresponding salary and wages  # noqa: E501

        :param status: The status of this SalaryAndWage.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError(
                "Invalid value for `status`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["Active", "Pending", "History", "None"]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status

    @property
    def payment_type(self):
        """Gets the payment_type of this SalaryAndWage.  # noqa: E501

        The type of the payment of the corresponding salary and wages  # noqa: E501

        :return: The payment_type of this SalaryAndWage.  # noqa: E501
        :rtype: str
        """
        return self._payment_type

    @payment_type.setter
    def payment_type(self, payment_type):
        """Sets the payment_type of this SalaryAndWage.

        The type of the payment of the corresponding salary and wages  # noqa: E501

        :param payment_type: The payment_type of this SalaryAndWage.  # noqa: E501
        :type: str
        """
        if payment_type is None:
            raise ValueError(
                "Invalid value for `payment_type`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["Salary", "Hourly", "None"]  # noqa: E501

        if payment_type:
            if payment_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `payment_type` ({0}), must be one of {1}".format(  # noqa: E501
                        payment_type, allowed_values
                    )
                )

        self._payment_type = payment_type



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class BrandingTheme(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "branding_theme_id": "str",
        "name": "str",
        "logo_url": "str",
        "type": "str",
        "sort_order": "int",
        "created_date_utc": "datetime[ms-format]",
    }

    attribute_map = {
        "branding_theme_id": "BrandingThemeID",
        "name": "Name",
        "logo_url": "LogoUrl",
        "type": "Type",
        "sort_order": "SortOrder",
        "created_date_utc": "CreatedDateUTC",
    }

    def __init__(
        self,
        branding_theme_id=None,
        name=None,
        logo_url=None,
        type=None,
        sort_order=None,
        created_date_utc=None,
    ):  # noqa: E501
        """BrandingTheme - a model defined in OpenAPI"""  # noqa: E501

        self._branding_theme_id = None
        self._name = None
        self._logo_url = None
        self._type = None
        self._sort_order = None
        self._created_date_utc = None
        self.discriminator = None

        if branding_theme_id is not None:
            self.branding_theme_id = branding_theme_id
        if name is not None:
            self.name = name
        if logo_url is not None:
            self.logo_url = logo_url
        if type is not None:
            self.type = type
        if sort_order is not None:
            self.sort_order = sort_order
        if created_date_utc is not None:
            self.created_date_utc = created_date_utc

    @property
    def branding_theme_id(self):
        """Gets the branding_theme_id of this BrandingTheme.  # noqa: E501

        Xero identifier  # noqa: E501

        :return: The branding_theme_id of this BrandingTheme.  # noqa: E501
        :rtype: str
        """
        return self._branding_theme_id

    @branding_theme_id.setter
    def branding_theme_id(self, branding_theme_id):
        """Sets the branding_theme_id of this BrandingTheme.

        Xero identifier  # noqa: E501

        :param branding_theme_id: The branding_theme_id of this BrandingTheme.  # noqa: E501
        :type: str
        """

        self._branding_theme_id = branding_theme_id

    @property
    def name(self):
        """Gets the name of this BrandingTheme.  # noqa: E501

        Name of branding theme  # noqa: E501

        :return: The name of this BrandingTheme.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BrandingTheme.

        Name of branding theme  # noqa: E501

        :param name: The name of this BrandingTheme.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def logo_url(self):
        """Gets the logo_url of this BrandingTheme.  # noqa: E501

        The location of the image file used as the logo on this branding theme  # noqa: E501

        :return: The logo_url of this BrandingTheme.  # noqa: E501
        :rtype: str
        """
        return self._logo_url

    @logo_url.setter
    def logo_url(self, logo_url):
        """Sets the logo_url of this BrandingTheme.

        The location of the image file used as the logo on this branding theme  # noqa: E501

        :param logo_url: The logo_url of this BrandingTheme.  # noqa: E501
        :type: str
        """

        self._logo_url = logo_url

    @property
    def type(self):
        """Gets the type of this BrandingTheme.  # noqa: E501

        Always INVOICE  # noqa: E501

        :return: The type of this BrandingTheme.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BrandingTheme.

        Always INVOICE  # noqa: E501

        :param type: The type of this BrandingTheme.  # noqa: E501
        :type: str
        """
        allowed_values = ["INVOICE", "None"]  # noqa: E501

        if type:
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                        type, allowed_values
                    )
                )

        self._type = type

    @property
    def sort_order(self):
        """Gets the sort_order of this BrandingTheme.  # noqa: E501

        Integer – ranked order of branding theme. The default branding theme has a value of 0  # noqa: E501

        :return: The sort_order of this BrandingTheme.  # noqa: E501
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this BrandingTheme.

        Integer – ranked order of branding theme. The default branding theme has a value of 0  # noqa: E501

        :param sort_order: The sort_order of this BrandingTheme.  # noqa: E501
        :type: int
        """

        self._sort_order = sort_order

    @property
    def created_date_utc(self):
        """Gets the created_date_utc of this BrandingTheme.  # noqa: E501

        UTC timestamp of creation date of branding theme  # noqa: E501

        :return: The created_date_utc of this BrandingTheme.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date_utc

    @created_date_utc.setter
    def created_date_utc(self, created_date_utc):
        """Sets the created_date_utc of this BrandingTheme.

        UTC timestamp of creation date of branding theme  # noqa: E501

        :param created_date_utc: The created_date_utc of this BrandingTheme.  # noqa: E501
        :type: datetime
        """

        self._created_date_utc = created_date_utc



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class BrandingThemes(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"branding_themes": "list[BrandingTheme]"}

    attribute_map = {"branding_themes": "BrandingThemes"}

    def __init__(self, branding_themes=None):  # noqa: E501
        """BrandingThemes - a model defined in OpenAPI"""  # noqa: E501

        self._branding_themes = None
        self.discriminator = None

        if branding_themes is not None:
            self.branding_themes = branding_themes

    @property
    def branding_themes(self):
        """Gets the branding_themes of this BrandingThemes.  # noqa: E501


        :return: The branding_themes of this BrandingThemes.  # noqa: E501
        :rtype: list[BrandingTheme]
        """
        return self._branding_themes

    @branding_themes.setter
    def branding_themes(self, branding_themes):
        """Sets the branding_themes of this BrandingThemes.


        :param branding_themes: The branding_themes of this BrandingThemes.  # noqa: E501
        :type: list[BrandingTheme]
        """

        self._branding_themes = branding_themes



# coding: utf-8

"""
    Xero Projects API

    This is the Xero Projects API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class TimeEntry(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "time_entry_id": "str",
        "user_id": "str",
        "project_id": "str",
        "task_id": "str",
        "date_utc": "datetime",
        "date_entered_utc": "datetime",
        "duration": "int",
        "description": "str",
        "status": "str",
    }

    attribute_map = {
        "time_entry_id": "timeEntryId",
        "user_id": "userId",
        "project_id": "projectId",
        "task_id": "taskId",
        "date_utc": "dateUtc",
        "date_entered_utc": "dateEnteredUtc",
        "duration": "duration",
        "description": "description",
        "status": "status",
    }

    def __init__(
        self,
        time_entry_id=None,
        user_id=None,
        project_id=None,
        task_id=None,
        date_utc=None,
        date_entered_utc=None,
        duration=None,
        description=None,
        status=None,
    ):  # noqa: E501
        """TimeEntry - a model defined in OpenAPI"""  # noqa: E501

        self._time_entry_id = None
        self._user_id = None
        self._project_id = None
        self._task_id = None
        self._date_utc = None
        self._date_entered_utc = None
        self._duration = None
        self._description = None
        self._status = None
        self.discriminator = None

        if time_entry_id is not None:
            self.time_entry_id = time_entry_id
        if user_id is not None:
            self.user_id = user_id
        if project_id is not None:
            self.project_id = project_id
        if task_id is not None:
            self.task_id = task_id
        if date_utc is not None:
            self.date_utc = date_utc
        if date_entered_utc is not None:
            self.date_entered_utc = date_entered_utc
        if duration is not None:
            self.duration = duration
        if description is not None:
            self.description = description
        if status is not None:
            self.status = status

    @property
    def time_entry_id(self):
        """Gets the time_entry_id of this TimeEntry.  # noqa: E501

        Identifier of the time entry.  # noqa: E501

        :return: The time_entry_id of this TimeEntry.  # noqa: E501
        :rtype: str
        """
        return self._time_entry_id

    @time_entry_id.setter
    def time_entry_id(self, time_entry_id):
        """Sets the time_entry_id of this TimeEntry.

        Identifier of the time entry.  # noqa: E501

        :param time_entry_id: The time_entry_id of this TimeEntry.  # noqa: E501
        :type: str
        """

        self._time_entry_id = time_entry_id

    @property
    def user_id(self):
        """Gets the user_id of this TimeEntry.  # noqa: E501

        The xero user identifier of the person who logged time.  # noqa: E501

        :return: The user_id of this TimeEntry.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this TimeEntry.

        The xero user identifier of the person who logged time.  # noqa: E501

        :param user_id: The user_id of this TimeEntry.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def project_id(self):
        """Gets the project_id of this TimeEntry.  # noqa: E501

        Identifier of the project, that the task (which the time entry is logged against) belongs to.  # noqa: E501

        :return: The project_id of this TimeEntry.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this TimeEntry.

        Identifier of the project, that the task (which the time entry is logged against) belongs to.  # noqa: E501

        :param project_id: The project_id of this TimeEntry.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def task_id(self):
        """Gets the task_id of this TimeEntry.  # noqa: E501

        Identifier of the task that time entry is logged against.  # noqa: E501

        :return: The task_id of this TimeEntry.  # noqa: E501
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this TimeEntry.

        Identifier of the task that time entry is logged against.  # noqa: E501

        :param task_id: The task_id of this TimeEntry.  # noqa: E501
        :type: str
        """

        self._task_id = task_id

    @property
    def date_utc(self):
        """Gets the date_utc of this TimeEntry.  # noqa: E501

        The date time that time entry is logged on. UTC Date Time in ISO-8601 format.  # noqa: E501

        :return: The date_utc of this TimeEntry.  # noqa: E501
        :rtype: datetime
        """
        return self._date_utc

    @date_utc.setter
    def date_utc(self, date_utc):
        """Sets the date_utc of this TimeEntry.

        The date time that time entry is logged on. UTC Date Time in ISO-8601 format.  # noqa: E501

        :param date_utc: The date_utc of this TimeEntry.  # noqa: E501
        :type: datetime
        """

        self._date_utc = date_utc

    @property
    def date_entered_utc(self):
        """Gets the date_entered_utc of this TimeEntry.  # noqa: E501

        The date time that time entry is created. UTC Date Time in ISO-8601 format. By default it is set to server time.  # noqa: E501

        :return: The date_entered_utc of this TimeEntry.  # noqa: E501
        :rtype: datetime
        """
        return self._date_entered_utc

    @date_entered_utc.setter
    def date_entered_utc(self, date_entered_utc):
        """Sets the date_entered_utc of this TimeEntry.

        The date time that time entry is created. UTC Date Time in ISO-8601 format. By default it is set to server time.  # noqa: E501

        :param date_entered_utc: The date_entered_utc of this TimeEntry.  # noqa: E501
        :type: datetime
        """

        self._date_entered_utc = date_entered_utc

    @property
    def duration(self):
        """Gets the duration of this TimeEntry.  # noqa: E501

        The duration of logged minutes.  # noqa: E501

        :return: The duration of this TimeEntry.  # noqa: E501
        :rtype: int
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this TimeEntry.

        The duration of logged minutes.  # noqa: E501

        :param duration: The duration of this TimeEntry.  # noqa: E501
        :type: int
        """

        self._duration = duration

    @property
    def description(self):
        """Gets the description of this TimeEntry.  # noqa: E501

        A description of the time entry.  # noqa: E501

        :return: The description of this TimeEntry.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TimeEntry.

        A description of the time entry.  # noqa: E501

        :param description: The description of this TimeEntry.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def status(self):
        """Gets the status of this TimeEntry.  # noqa: E501

        Status of the time entry. By default a time entry is created with status of `ACTIVE`. A `LOCKED` state indicates that the time entry is currently changing state (for example being invoiced). Updates are not allowed when in this state. It will have a status of INVOICED once it is invoiced.  # noqa: E501

        :return: The status of this TimeEntry.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this TimeEntry.

        Status of the time entry. By default a time entry is created with status of `ACTIVE`. A `LOCKED` state indicates that the time entry is currently changing state (for example being invoiced). Updates are not allowed when in this state. It will have a status of INVOICED once it is invoiced.  # noqa: E501

        :param status: The status of this TimeEntry.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACTIVE", "LOCKED", "None"]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class TaxDeclaration(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "employee_id": "str",
        "employment_basis": "EmploymentBasis",
        "tfn_exemption_type": "TFNExemptionType",
        "tax_file_number": "str",
        "australian_resident_for_tax_purposes": "bool",
        "residency_status": "ResidencyStatus",
        "tax_free_threshold_claimed": "bool",
        "tax_offset_estimated_amount": "float",
        "has_help_debt": "bool",
        "has_sfss_debt": "bool",
        "has_trade_support_loan_debt": "bool",
        "upward_variation_tax_withholding_amount": "float",
        "eligible_to_receive_leave_loading": "bool",
        "approved_withholding_variation_percentage": "float",
        "has_student_startup_loan": "bool",
        "updated_date_utc": "datetime[ms-format]",
    }

    attribute_map = {
        "employee_id": "EmployeeID",
        "employment_basis": "EmploymentBasis",
        "tfn_exemption_type": "TFNExemptionType",
        "tax_file_number": "TaxFileNumber",
        "australian_resident_for_tax_purposes": "AustralianResidentForTaxPurposes",
        "residency_status": "ResidencyStatus",
        "tax_free_threshold_claimed": "TaxFreeThresholdClaimed",
        "tax_offset_estimated_amount": "TaxOffsetEstimatedAmount",
        "has_help_debt": "HasHELPDebt",
        "has_sfss_debt": "HasSFSSDebt",
        "has_trade_support_loan_debt": "HasTradeSupportLoanDebt",
        "upward_variation_tax_withholding_amount": "UpwardVariationTaxWithholdingAmount",
        "eligible_to_receive_leave_loading": "EligibleToReceiveLeaveLoading",
        "approved_withholding_variation_percentage": "ApprovedWithholdingVariationPercentage",
        "has_student_startup_loan": "HasStudentStartupLoan",
        "updated_date_utc": "UpdatedDateUTC",
    }

    def __init__(
        self,
        employee_id=None,
        employment_basis=None,
        tfn_exemption_type=None,
        tax_file_number=None,
        australian_resident_for_tax_purposes=None,
        residency_status=None,
        tax_free_threshold_claimed=None,
        tax_offset_estimated_amount=None,
        has_help_debt=None,
        has_sfss_debt=None,
        has_trade_support_loan_debt=None,
        upward_variation_tax_withholding_amount=None,
        eligible_to_receive_leave_loading=None,
        approved_withholding_variation_percentage=None,
        has_student_startup_loan=None,
        updated_date_utc=None,
    ):  # noqa: E501
        """TaxDeclaration - a model defined in OpenAPI"""  # noqa: E501

        self._employee_id = None
        self._employment_basis = None
        self._tfn_exemption_type = None
        self._tax_file_number = None
        self._australian_resident_for_tax_purposes = None
        self._residency_status = None
        self._tax_free_threshold_claimed = None
        self._tax_offset_estimated_amount = None
        self._has_help_debt = None
        self._has_sfss_debt = None
        self._has_trade_support_loan_debt = None
        self._upward_variation_tax_withholding_amount = None
        self._eligible_to_receive_leave_loading = None
        self._approved_withholding_variation_percentage = None
        self._has_student_startup_loan = None
        self._updated_date_utc = None
        self.discriminator = None

        if employee_id is not None:
            self.employee_id = employee_id
        if employment_basis is not None:
            self.employment_basis = employment_basis
        if tfn_exemption_type is not None:
            self.tfn_exemption_type = tfn_exemption_type
        if tax_file_number is not None:
            self.tax_file_number = tax_file_number
        if australian_resident_for_tax_purposes is not None:
            self.australian_resident_for_tax_purposes = (
                australian_resident_for_tax_purposes
            )
        if residency_status is not None:
            self.residency_status = residency_status
        if tax_free_threshold_claimed is not None:
            self.tax_free_threshold_claimed = tax_free_threshold_claimed
        if tax_offset_estimated_amount is not None:
            self.tax_offset_estimated_amount = tax_offset_estimated_amount
        if has_help_debt is not None:
            self.has_help_debt = has_help_debt
        if has_sfss_debt is not None:
            self.has_sfss_debt = has_sfss_debt
        if has_trade_support_loan_debt is not None:
            self.has_trade_support_loan_debt = has_trade_support_loan_debt
        if upward_variation_tax_withholding_amount is not None:
            self.upward_variation_tax_withholding_amount = (
                upward_variation_tax_withholding_amount
            )
        if eligible_to_receive_leave_loading is not None:
            self.eligible_to_receive_leave_loading = eligible_to_receive_leave_loading
        if approved_withholding_variation_percentage is not None:
            self.approved_withholding_variation_percentage = (
                approved_withholding_variation_percentage
            )
        if has_student_startup_loan is not None:
            self.has_student_startup_loan = has_student_startup_loan
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc

    @property
    def employee_id(self):
        """Gets the employee_id of this TaxDeclaration.  # noqa: E501

        Address line 1 for employee home address  # noqa: E501

        :return: The employee_id of this TaxDeclaration.  # noqa: E501
        :rtype: str
        """
        return self._employee_id

    @employee_id.setter
    def employee_id(self, employee_id):
        """Sets the employee_id of this TaxDeclaration.

        Address line 1 for employee home address  # noqa: E501

        :param employee_id: The employee_id of this TaxDeclaration.  # noqa: E501
        :type: str
        """

        self._employee_id = employee_id

    @property
    def employment_basis(self):
        """Gets the employment_basis of this TaxDeclaration.  # noqa: E501


        :return: The employment_basis of this TaxDeclaration.  # noqa: E501
        :rtype: EmploymentBasis
        """
        return self._employment_basis

    @employment_basis.setter
    def employment_basis(self, employment_basis):
        """Sets the employment_basis of this TaxDeclaration.


        :param employment_basis: The employment_basis of this TaxDeclaration.  # noqa: E501
        :type: EmploymentBasis
        """

        self._employment_basis = employment_basis

    @property
    def tfn_exemption_type(self):
        """Gets the tfn_exemption_type of this TaxDeclaration.  # noqa: E501


        :return: The tfn_exemption_type of this TaxDeclaration.  # noqa: E501
        :rtype: TFNExemptionType
        """
        return self._tfn_exemption_type

    @tfn_exemption_type.setter
    def tfn_exemption_type(self, tfn_exemption_type):
        """Sets the tfn_exemption_type of this TaxDeclaration.


        :param tfn_exemption_type: The tfn_exemption_type of this TaxDeclaration.  # noqa: E501
        :type: TFNExemptionType
        """

        self._tfn_exemption_type = tfn_exemption_type

    @property
    def tax_file_number(self):
        """Gets the tax_file_number of this TaxDeclaration.  # noqa: E501

        The tax file number e.g 123123123.  # noqa: E501

        :return: The tax_file_number of this TaxDeclaration.  # noqa: E501
        :rtype: str
        """
        return self._tax_file_number

    @tax_file_number.setter
    def tax_file_number(self, tax_file_number):
        """Sets the tax_file_number of this TaxDeclaration.

        The tax file number e.g 123123123.  # noqa: E501

        :param tax_file_number: The tax_file_number of this TaxDeclaration.  # noqa: E501
        :type: str
        """

        self._tax_file_number = tax_file_number

    @property
    def australian_resident_for_tax_purposes(self):
        """Gets the australian_resident_for_tax_purposes of this TaxDeclaration.  # noqa: E501

        If the employee is Australian resident for tax purposes. e.g true or false  # noqa: E501

        :return: The australian_resident_for_tax_purposes of this TaxDeclaration.  # noqa: E501
        :rtype: bool
        """
        return self._australian_resident_for_tax_purposes

    @australian_resident_for_tax_purposes.setter
    def australian_resident_for_tax_purposes(
        self, australian_resident_for_tax_purposes
    ):
        """Sets the australian_resident_for_tax_purposes of this TaxDeclaration.

        If the employee is Australian resident for tax purposes. e.g true or false  # noqa: E501

        :param australian_resident_for_tax_purposes: The australian_resident_for_tax_purposes of this TaxDeclaration.  # noqa: E501
        :type: bool
        """

        self._australian_resident_for_tax_purposes = (
            australian_resident_for_tax_purposes
        )

    @property
    def residency_status(self):
        """Gets the residency_status of this TaxDeclaration.  # noqa: E501


        :return: The residency_status of this TaxDeclaration.  # noqa: E501
        :rtype: ResidencyStatus
        """
        return self._residency_status

    @residency_status.setter
    def residency_status(self, residency_status):
        """Sets the residency_status of this TaxDeclaration.


        :param residency_status: The residency_status of this TaxDeclaration.  # noqa: E501
        :type: ResidencyStatus
        """

        self._residency_status = residency_status

    @property
    def tax_free_threshold_claimed(self):
        """Gets the tax_free_threshold_claimed of this TaxDeclaration.  # noqa: E501

        If tax free threshold claimed. e.g true or false  # noqa: E501

        :return: The tax_free_threshold_claimed of this TaxDeclaration.  # noqa: E501
        :rtype: bool
        """
        return self._tax_free_threshold_claimed

    @tax_free_threshold_claimed.setter
    def tax_free_threshold_claimed(self, tax_free_threshold_claimed):
        """Sets the tax_free_threshold_claimed of this TaxDeclaration.

        If tax free threshold claimed. e.g true or false  # noqa: E501

        :param tax_free_threshold_claimed: The tax_free_threshold_claimed of this TaxDeclaration.  # noqa: E501
        :type: bool
        """

        self._tax_free_threshold_claimed = tax_free_threshold_claimed

    @property
    def tax_offset_estimated_amount(self):
        """Gets the tax_offset_estimated_amount of this TaxDeclaration.  # noqa: E501

        If has tax offset estimated then the tax offset estimated amount. e.g 100  # noqa: E501

        :return: The tax_offset_estimated_amount of this TaxDeclaration.  # noqa: E501
        :rtype: float
        """
        return self._tax_offset_estimated_amount

    @tax_offset_estimated_amount.setter
    def tax_offset_estimated_amount(self, tax_offset_estimated_amount):
        """Sets the tax_offset_estimated_amount of this TaxDeclaration.

        If has tax offset estimated then the tax offset estimated amount. e.g 100  # noqa: E501

        :param tax_offset_estimated_amount: The tax_offset_estimated_amount of this TaxDeclaration.  # noqa: E501
        :type: float
        """

        self._tax_offset_estimated_amount = tax_offset_estimated_amount

    @property
    def has_help_debt(self):
        """Gets the has_help_debt of this TaxDeclaration.  # noqa: E501

        If employee has HECS or HELP debt. e.g true or false  # noqa: E501

        :return: The has_help_debt of this TaxDeclaration.  # noqa: E501
        :rtype: bool
        """
        return self._has_help_debt

    @has_help_debt.setter
    def has_help_debt(self, has_help_debt):
        """Sets the has_help_debt of this TaxDeclaration.

        If employee has HECS or HELP debt. e.g true or false  # noqa: E501

        :param has_help_debt: The has_help_debt of this TaxDeclaration.  # noqa: E501
        :type: bool
        """

        self._has_help_debt = has_help_debt

    @property
    def has_sfss_debt(self):
        """Gets the has_sfss_debt of this TaxDeclaration.  # noqa: E501

        If employee has financial supplement debt. e.g true or false  # noqa: E501

        :return: The has_sfss_debt of this TaxDeclaration.  # noqa: E501
        :rtype: bool
        """
        return self._has_sfss_debt

    @has_sfss_debt.setter
    def has_sfss_debt(self, has_sfss_debt):
        """Sets the has_sfss_debt of this TaxDeclaration.

        If employee has financial supplement debt. e.g true or false  # noqa: E501

        :param has_sfss_debt: The has_sfss_debt of this TaxDeclaration.  # noqa: E501
        :type: bool
        """

        self._has_sfss_debt = has_sfss_debt

    @property
    def has_trade_support_loan_debt(self):
        """Gets the has_trade_support_loan_debt of this TaxDeclaration.  # noqa: E501

        If employee has trade support loan. e.g true or false  # noqa: E501

        :return: The has_trade_support_loan_debt of this TaxDeclaration.  # noqa: E501
        :rtype: bool
        """
        return self._has_trade_support_loan_debt

    @has_trade_support_loan_debt.setter
    def has_trade_support_loan_debt(self, has_trade_support_loan_debt):
        """Sets the has_trade_support_loan_debt of this TaxDeclaration.

        If employee has trade support loan. e.g true or false  # noqa: E501

        :param has_trade_support_loan_debt: The has_trade_support_loan_debt of this TaxDeclaration.  # noqa: E501
        :type: bool
        """

        self._has_trade_support_loan_debt = has_trade_support_loan_debt

    @property
    def upward_variation_tax_withholding_amount(self):
        """Gets the upward_variation_tax_withholding_amount of this TaxDeclaration.  # noqa: E501

        If the employee has requested that additional tax be withheld each pay run. e.g 50  # noqa: E501

        :return: The upward_variation_tax_withholding_amount of this TaxDeclaration.  # noqa: E501
        :rtype: float
        """
        return self._upward_variation_tax_withholding_amount

    @upward_variation_tax_withholding_amount.setter
    def upward_variation_tax_withholding_amount(
        self, upward_variation_tax_withholding_amount
    ):
        """Sets the upward_variation_tax_withholding_amount of this TaxDeclaration.

        If the employee has requested that additional tax be withheld each pay run. e.g 50  # noqa: E501

        :param upward_variation_tax_withholding_amount: The upward_variation_tax_withholding_amount of this TaxDeclaration.  # noqa: E501
        :type: float
        """

        self._upward_variation_tax_withholding_amount = (
            upward_variation_tax_withholding_amount
        )

    @property
    def eligible_to_receive_leave_loading(self):
        """Gets the eligible_to_receive_leave_loading of this TaxDeclaration.  # noqa: E501

        If the employee is eligible to receive an additional percentage on top of ordinary earnings when they take leave (typically 17.5%). e.g true or false  # noqa: E501

        :return: The eligible_to_receive_leave_loading of this TaxDeclaration.  # noqa: E501
        :rtype: bool
        """
        return self._eligible_to_receive_leave_loading

    @eligible_to_receive_leave_loading.setter
    def eligible_to_receive_leave_loading(self, eligible_to_receive_leave_loading):
        """Sets the eligible_to_receive_leave_loading of this TaxDeclaration.

        If the employee is eligible to receive an additional percentage on top of ordinary earnings when they take leave (typically 17.5%). e.g true or false  # noqa: E501

        :param eligible_to_receive_leave_loading: The eligible_to_receive_leave_loading of this TaxDeclaration.  # noqa: E501
        :type: bool
        """

        self._eligible_to_receive_leave_loading = eligible_to_receive_leave_loading

    @property
    def approved_withholding_variation_percentage(self):
        """Gets the approved_withholding_variation_percentage of this TaxDeclaration.  # noqa: E501

        If the employee has approved withholding variation. e.g (0 - 100)  # noqa: E501

        :return: The approved_withholding_variation_percentage of this TaxDeclaration.  # noqa: E501
        :rtype: float
        """
        return self._approved_withholding_variation_percentage

    @approved_withholding_variation_percentage.setter
    def approved_withholding_variation_percentage(
        self, approved_withholding_variation_percentage
    ):
        """Sets the approved_withholding_variation_percentage of this TaxDeclaration.

        If the employee has approved withholding variation. e.g (0 - 100)  # noqa: E501

        :param approved_withholding_variation_percentage: The approved_withholding_variation_percentage of this TaxDeclaration.  # noqa: E501
        :type: float
        """

        self._approved_withholding_variation_percentage = (
            approved_withholding_variation_percentage
        )

    @property
    def has_student_startup_loan(self):
        """Gets the has_student_startup_loan of this TaxDeclaration.  # noqa: E501

        If the employee is eligible for student startup loan rules  # noqa: E501

        :return: The has_student_startup_loan of this TaxDeclaration.  # noqa: E501
        :rtype: bool
        """
        return self._has_student_startup_loan

    @has_student_startup_loan.setter
    def has_student_startup_loan(self, has_student_startup_loan):
        """Sets the has_student_startup_loan of this TaxDeclaration.

        If the employee is eligible for student startup loan rules  # noqa: E501

        :param has_student_startup_loan: The has_student_startup_loan of this TaxDeclaration.  # noqa: E501
        :type: bool
        """

        self._has_student_startup_loan = has_student_startup_loan

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this TaxDeclaration.  # noqa: E501

        Last modified timestamp  # noqa: E501

        :return: The updated_date_utc of this TaxDeclaration.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this TaxDeclaration.

        Last modified timestamp  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this TaxDeclaration.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class LeaveType(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "name": "str",
        "type_of_units": "str",
        "leave_type_id": "str",
        "normal_entitlement": "float",
        "leave_loading_rate": "float",
        "updated_date_utc": "datetime[ms-format]",
        "is_paid_leave": "bool",
        "show_on_payslip": "bool",
        "current_record": "bool",
    }

    attribute_map = {
        "name": "Name",
        "type_of_units": "TypeOfUnits",
        "leave_type_id": "LeaveTypeID",
        "normal_entitlement": "NormalEntitlement",
        "leave_loading_rate": "LeaveLoadingRate",
        "updated_date_utc": "UpdatedDateUTC",
        "is_paid_leave": "IsPaidLeave",
        "show_on_payslip": "ShowOnPayslip",
        "current_record": "CurrentRecord",
    }

    def __init__(
        self,
        name=None,
        type_of_units=None,
        leave_type_id=None,
        normal_entitlement=None,
        leave_loading_rate=None,
        updated_date_utc=None,
        is_paid_leave=None,
        show_on_payslip=None,
        current_record=None,
    ):  # noqa: E501
        """LeaveType - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._type_of_units = None
        self._leave_type_id = None
        self._normal_entitlement = None
        self._leave_loading_rate = None
        self._updated_date_utc = None
        self._is_paid_leave = None
        self._show_on_payslip = None
        self._current_record = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if type_of_units is not None:
            self.type_of_units = type_of_units
        if leave_type_id is not None:
            self.leave_type_id = leave_type_id
        if normal_entitlement is not None:
            self.normal_entitlement = normal_entitlement
        if leave_loading_rate is not None:
            self.leave_loading_rate = leave_loading_rate
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if is_paid_leave is not None:
            self.is_paid_leave = is_paid_leave
        if show_on_payslip is not None:
            self.show_on_payslip = show_on_payslip
        if current_record is not None:
            self.current_record = current_record

    @property
    def name(self):
        """Gets the name of this LeaveType.  # noqa: E501

        Name of the earnings rate (max length = 100)  # noqa: E501

        :return: The name of this LeaveType.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LeaveType.

        Name of the earnings rate (max length = 100)  # noqa: E501

        :param name: The name of this LeaveType.  # noqa: E501
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError(
                "Invalid value for `name`, "
                "length must be less than or equal to `100`"
            )  # noqa: E501

        self._name = name

    @property
    def type_of_units(self):
        """Gets the type_of_units of this LeaveType.  # noqa: E501

        The type of units by which leave entitlements are normally tracked. These are typically the same as the type of units used for the employee’s ordinary earnings rate  # noqa: E501

        :return: The type_of_units of this LeaveType.  # noqa: E501
        :rtype: str
        """
        return self._type_of_units

    @type_of_units.setter
    def type_of_units(self, type_of_units):
        """Sets the type_of_units of this LeaveType.

        The type of units by which leave entitlements are normally tracked. These are typically the same as the type of units used for the employee’s ordinary earnings rate  # noqa: E501

        :param type_of_units: The type_of_units of this LeaveType.  # noqa: E501
        :type: str
        """

        self._type_of_units = type_of_units

    @property
    def leave_type_id(self):
        """Gets the leave_type_id of this LeaveType.  # noqa: E501

        Xero identifier  # noqa: E501

        :return: The leave_type_id of this LeaveType.  # noqa: E501
        :rtype: str
        """
        return self._leave_type_id

    @leave_type_id.setter
    def leave_type_id(self, leave_type_id):
        """Sets the leave_type_id of this LeaveType.

        Xero identifier  # noqa: E501

        :param leave_type_id: The leave_type_id of this LeaveType.  # noqa: E501
        :type: str
        """

        self._leave_type_id = leave_type_id

    @property
    def normal_entitlement(self):
        """Gets the normal_entitlement of this LeaveType.  # noqa: E501

        The number of units the employee is entitled to each year  # noqa: E501

        :return: The normal_entitlement of this LeaveType.  # noqa: E501
        :rtype: float
        """
        return self._normal_entitlement

    @normal_entitlement.setter
    def normal_entitlement(self, normal_entitlement):
        """Sets the normal_entitlement of this LeaveType.

        The number of units the employee is entitled to each year  # noqa: E501

        :param normal_entitlement: The normal_entitlement of this LeaveType.  # noqa: E501
        :type: float
        """

        self._normal_entitlement = normal_entitlement

    @property
    def leave_loading_rate(self):
        """Gets the leave_loading_rate of this LeaveType.  # noqa: E501

        Enter an amount here if your organisation pays an additional percentage on top of ordinary earnings when your employees take leave (typically 17.5%)  # noqa: E501

        :return: The leave_loading_rate of this LeaveType.  # noqa: E501
        :rtype: float
        """
        return self._leave_loading_rate

    @leave_loading_rate.setter
    def leave_loading_rate(self, leave_loading_rate):
        """Sets the leave_loading_rate of this LeaveType.

        Enter an amount here if your organisation pays an additional percentage on top of ordinary earnings when your employees take leave (typically 17.5%)  # noqa: E501

        :param leave_loading_rate: The leave_loading_rate of this LeaveType.  # noqa: E501
        :type: float
        """

        self._leave_loading_rate = leave_loading_rate

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this LeaveType.  # noqa: E501

        Last modified timestamp  # noqa: E501

        :return: The updated_date_utc of this LeaveType.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this LeaveType.

        Last modified timestamp  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this LeaveType.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def is_paid_leave(self):
        """Gets the is_paid_leave of this LeaveType.  # noqa: E501

        Set this to indicate that an employee will be paid when taking this type of leave  # noqa: E501

        :return: The is_paid_leave of this LeaveType.  # noqa: E501
        :rtype: bool
        """
        return self._is_paid_leave

    @is_paid_leave.setter
    def is_paid_leave(self, is_paid_leave):
        """Sets the is_paid_leave of this LeaveType.

        Set this to indicate that an employee will be paid when taking this type of leave  # noqa: E501

        :param is_paid_leave: The is_paid_leave of this LeaveType.  # noqa: E501
        :type: bool
        """

        self._is_paid_leave = is_paid_leave

    @property
    def show_on_payslip(self):
        """Gets the show_on_payslip of this LeaveType.  # noqa: E501

        Set this if you want a balance for this leave type to be shown on your employee’s payslips  # noqa: E501

        :return: The show_on_payslip of this LeaveType.  # noqa: E501
        :rtype: bool
        """
        return self._show_on_payslip

    @show_on_payslip.setter
    def show_on_payslip(self, show_on_payslip):
        """Sets the show_on_payslip of this LeaveType.

        Set this if you want a balance for this leave type to be shown on your employee’s payslips  # noqa: E501

        :param show_on_payslip: The show_on_payslip of this LeaveType.  # noqa: E501
        :type: bool
        """

        self._show_on_payslip = show_on_payslip

    @property
    def current_record(self):
        """Gets the current_record of this LeaveType.  # noqa: E501

        Is the current record  # noqa: E501

        :return: The current_record of this LeaveType.  # noqa: E501
        :rtype: bool
        """
        return self._current_record

    @current_record.setter
    def current_record(self, current_record):
        """Sets the current_record of this LeaveType.

        Is the current record  # noqa: E501

        :param current_record: The current_record of this LeaveType.  # noqa: E501
        :type: bool
        """

        self._current_record = current_record



# coding: utf-8

"""
    Xero Projects API

    This is the Xero Projects API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Task(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "task_id": "str",
        "name": "str",
        "rate": "Amount",
        "charge_type": "ChargeType",
        "estimate_minutes": "float",
        "project_id": "str",
        "total_minutes": "float",
        "total_amount": "Amount",
        "minutes_invoiced": "float",
        "minutes_to_be_invoiced": "float",
        "fixed_minutes": "float",
        "non_chargeable_minutes": "float",
        "amount_to_be_invoiced": "Amount",
        "amount_invoiced": "Amount",
        "status": "str",
    }

    attribute_map = {
        "task_id": "taskId",
        "name": "name",
        "rate": "rate",
        "charge_type": "chargeType",
        "estimate_minutes": "estimateMinutes",
        "project_id": "projectId",
        "total_minutes": "totalMinutes",
        "total_amount": "totalAmount",
        "minutes_invoiced": "minutesInvoiced",
        "minutes_to_be_invoiced": "minutesToBeInvoiced",
        "fixed_minutes": "fixedMinutes",
        "non_chargeable_minutes": "nonChargeableMinutes",
        "amount_to_be_invoiced": "amountToBeInvoiced",
        "amount_invoiced": "amountInvoiced",
        "status": "status",
    }

    def __init__(
        self,
        task_id=None,
        name=None,
        rate=None,
        charge_type=None,
        estimate_minutes=None,
        project_id=None,
        total_minutes=None,
        total_amount=None,
        minutes_invoiced=None,
        minutes_to_be_invoiced=None,
        fixed_minutes=None,
        non_chargeable_minutes=None,
        amount_to_be_invoiced=None,
        amount_invoiced=None,
        status=None,
    ):  # noqa: E501
        """Task - a model defined in OpenAPI"""  # noqa: E501

        self._task_id = None
        self._name = None
        self._rate = None
        self._charge_type = None
        self._estimate_minutes = None
        self._project_id = None
        self._total_minutes = None
        self._total_amount = None
        self._minutes_invoiced = None
        self._minutes_to_be_invoiced = None
        self._fixed_minutes = None
        self._non_chargeable_minutes = None
        self._amount_to_be_invoiced = None
        self._amount_invoiced = None
        self._status = None
        self.discriminator = None

        if task_id is not None:
            self.task_id = task_id
        if name is not None:
            self.name = name
        if rate is not None:
            self.rate = rate
        if charge_type is not None:
            self.charge_type = charge_type
        if estimate_minutes is not None:
            self.estimate_minutes = estimate_minutes
        if project_id is not None:
            self.project_id = project_id
        if total_minutes is not None:
            self.total_minutes = total_minutes
        if total_amount is not None:
            self.total_amount = total_amount
        if minutes_invoiced is not None:
            self.minutes_invoiced = minutes_invoiced
        if minutes_to_be_invoiced is not None:
            self.minutes_to_be_invoiced = minutes_to_be_invoiced
        if fixed_minutes is not None:
            self.fixed_minutes = fixed_minutes
        if non_chargeable_minutes is not None:
            self.non_chargeable_minutes = non_chargeable_minutes
        if amount_to_be_invoiced is not None:
            self.amount_to_be_invoiced = amount_to_be_invoiced
        if amount_invoiced is not None:
            self.amount_invoiced = amount_invoiced
        if status is not None:
            self.status = status

    @property
    def task_id(self):
        """Gets the task_id of this Task.  # noqa: E501

        Identifier of the task.  # noqa: E501

        :return: The task_id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this Task.

        Identifier of the task.  # noqa: E501

        :param task_id: The task_id of this Task.  # noqa: E501
        :type: str
        """

        self._task_id = task_id

    @property
    def name(self):
        """Gets the name of this Task.  # noqa: E501

        Name of the task.  # noqa: E501

        :return: The name of this Task.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Task.

        Name of the task.  # noqa: E501

        :param name: The name of this Task.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def rate(self):
        """Gets the rate of this Task.  # noqa: E501


        :return: The rate of this Task.  # noqa: E501
        :rtype: Amount
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        """Sets the rate of this Task.


        :param rate: The rate of this Task.  # noqa: E501
        :type: Amount
        """

        self._rate = rate

    @property
    def charge_type(self):
        """Gets the charge_type of this Task.  # noqa: E501


        :return: The charge_type of this Task.  # noqa: E501
        :rtype: ChargeType
        """
        return self._charge_type

    @charge_type.setter
    def charge_type(self, charge_type):
        """Sets the charge_type of this Task.


        :param charge_type: The charge_type of this Task.  # noqa: E501
        :type: ChargeType
        """

        self._charge_type = charge_type

    @property
    def estimate_minutes(self):
        """Gets the estimate_minutes of this Task.  # noqa: E501

        An estimated time to perform the task  # noqa: E501

        :return: The estimate_minutes of this Task.  # noqa: E501
        :rtype: float
        """
        return self._estimate_minutes

    @estimate_minutes.setter
    def estimate_minutes(self, estimate_minutes):
        """Sets the estimate_minutes of this Task.

        An estimated time to perform the task  # noqa: E501

        :param estimate_minutes: The estimate_minutes of this Task.  # noqa: E501
        :type: float
        """

        self._estimate_minutes = estimate_minutes

    @property
    def project_id(self):
        """Gets the project_id of this Task.  # noqa: E501

        Identifier of the project task belongs to.  # noqa: E501

        :return: The project_id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this Task.

        Identifier of the project task belongs to.  # noqa: E501

        :param project_id: The project_id of this Task.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def total_minutes(self):
        """Gets the total_minutes of this Task.  # noqa: E501

        Total minutes which have been logged against the task. Logged by assigning a time entry to a task  # noqa: E501

        :return: The total_minutes of this Task.  # noqa: E501
        :rtype: float
        """
        return self._total_minutes

    @total_minutes.setter
    def total_minutes(self, total_minutes):
        """Sets the total_minutes of this Task.

        Total minutes which have been logged against the task. Logged by assigning a time entry to a task  # noqa: E501

        :param total_minutes: The total_minutes of this Task.  # noqa: E501
        :type: float
        """

        self._total_minutes = total_minutes

    @property
    def total_amount(self):
        """Gets the total_amount of this Task.  # noqa: E501


        :return: The total_amount of this Task.  # noqa: E501
        :rtype: Amount
        """
        return self._total_amount

    @total_amount.setter
    def total_amount(self, total_amount):
        """Sets the total_amount of this Task.


        :param total_amount: The total_amount of this Task.  # noqa: E501
        :type: Amount
        """

        self._total_amount = total_amount

    @property
    def minutes_invoiced(self):
        """Gets the minutes_invoiced of this Task.  # noqa: E501

        Minutes on this task which have been invoiced.  # noqa: E501

        :return: The minutes_invoiced of this Task.  # noqa: E501
        :rtype: float
        """
        return self._minutes_invoiced

    @minutes_invoiced.setter
    def minutes_invoiced(self, minutes_invoiced):
        """Sets the minutes_invoiced of this Task.

        Minutes on this task which have been invoiced.  # noqa: E501

        :param minutes_invoiced: The minutes_invoiced of this Task.  # noqa: E501
        :type: float
        """

        self._minutes_invoiced = minutes_invoiced

    @property
    def minutes_to_be_invoiced(self):
        """Gets the minutes_to_be_invoiced of this Task.  # noqa: E501

        Minutes on this task which have not been invoiced.  # noqa: E501

        :return: The minutes_to_be_invoiced of this Task.  # noqa: E501
        :rtype: float
        """
        return self._minutes_to_be_invoiced

    @minutes_to_be_invoiced.setter
    def minutes_to_be_invoiced(self, minutes_to_be_invoiced):
        """Sets the minutes_to_be_invoiced of this Task.

        Minutes on this task which have not been invoiced.  # noqa: E501

        :param minutes_to_be_invoiced: The minutes_to_be_invoiced of this Task.  # noqa: E501
        :type: float
        """

        self._minutes_to_be_invoiced = minutes_to_be_invoiced

    @property
    def fixed_minutes(self):
        """Gets the fixed_minutes of this Task.  # noqa: E501

        Minutes logged against this task if its charge type is `FIXED`.  # noqa: E501

        :return: The fixed_minutes of this Task.  # noqa: E501
        :rtype: float
        """
        return self._fixed_minutes

    @fixed_minutes.setter
    def fixed_minutes(self, fixed_minutes):
        """Sets the fixed_minutes of this Task.

        Minutes logged against this task if its charge type is `FIXED`.  # noqa: E501

        :param fixed_minutes: The fixed_minutes of this Task.  # noqa: E501
        :type: float
        """

        self._fixed_minutes = fixed_minutes

    @property
    def non_chargeable_minutes(self):
        """Gets the non_chargeable_minutes of this Task.  # noqa: E501

        Minutes logged against this task if its charge type is `NON_CHARGEABLE`.  # noqa: E501

        :return: The non_chargeable_minutes of this Task.  # noqa: E501
        :rtype: float
        """
        return self._non_chargeable_minutes

    @non_chargeable_minutes.setter
    def non_chargeable_minutes(self, non_chargeable_minutes):
        """Sets the non_chargeable_minutes of this Task.

        Minutes logged against this task if its charge type is `NON_CHARGEABLE`.  # noqa: E501

        :param non_chargeable_minutes: The non_chargeable_minutes of this Task.  # noqa: E501
        :type: float
        """

        self._non_chargeable_minutes = non_chargeable_minutes

    @property
    def amount_to_be_invoiced(self):
        """Gets the amount_to_be_invoiced of this Task.  # noqa: E501


        :return: The amount_to_be_invoiced of this Task.  # noqa: E501
        :rtype: Amount
        """
        return self._amount_to_be_invoiced

    @amount_to_be_invoiced.setter
    def amount_to_be_invoiced(self, amount_to_be_invoiced):
        """Sets the amount_to_be_invoiced of this Task.


        :param amount_to_be_invoiced: The amount_to_be_invoiced of this Task.  # noqa: E501
        :type: Amount
        """

        self._amount_to_be_invoiced = amount_to_be_invoiced

    @property
    def amount_invoiced(self):
        """Gets the amount_invoiced of this Task.  # noqa: E501


        :return: The amount_invoiced of this Task.  # noqa: E501
        :rtype: Amount
        """
        return self._amount_invoiced

    @amount_invoiced.setter
    def amount_invoiced(self, amount_invoiced):
        """Sets the amount_invoiced of this Task.


        :param amount_invoiced: The amount_invoiced of this Task.  # noqa: E501
        :type: Amount
        """

        self._amount_invoiced = amount_invoiced

    @property
    def status(self):
        """Gets the status of this Task.  # noqa: E501

        Status of the task. When a task of ChargeType is `FIXED` and the rate amount is invoiced the status will be set to `INVOICED` and can't be modified. A task with ChargeType of `TIME` or `NON_CHARGEABLE` cannot have a status of `INVOICED`. A `LOCKED` state indicates that the task is currently changing state (for example being invoiced) and can't be modified.  # noqa: E501

        :return: The status of this Task.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Task.

        Status of the task. When a task of ChargeType is `FIXED` and the rate amount is invoiced the status will be set to `INVOICED` and can't be modified. A task with ChargeType of `TIME` or `NON_CHARGEABLE` cannot have a status of `INVOICED`. A `LOCKED` state indicates that the task is currently changing state (for example being invoiced) and can't be modified.  # noqa: E501

        :param status: The status of this Task.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACTIVE", "INVOICED", "LOCKED", "None"]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class LinkedTransaction(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "source_transaction_id": "str",
        "source_line_item_id": "str",
        "contact_id": "str",
        "target_transaction_id": "str",
        "target_line_item_id": "str",
        "linked_transaction_id": "str",
        "status": "str",
        "type": "str",
        "updated_date_utc": "datetime[ms-format]",
        "source_transaction_type_code": "str",
        "validation_errors": "list[ValidationError]",
    }

    attribute_map = {
        "source_transaction_id": "SourceTransactionID",
        "source_line_item_id": "SourceLineItemID",
        "contact_id": "ContactID",
        "target_transaction_id": "TargetTransactionID",
        "target_line_item_id": "TargetLineItemID",
        "linked_transaction_id": "LinkedTransactionID",
        "status": "Status",
        "type": "Type",
        "updated_date_utc": "UpdatedDateUTC",
        "source_transaction_type_code": "SourceTransactionTypeCode",
        "validation_errors": "ValidationErrors",
    }

    def __init__(
        self,
        source_transaction_id=None,
        source_line_item_id=None,
        contact_id=None,
        target_transaction_id=None,
        target_line_item_id=None,
        linked_transaction_id=None,
        status=None,
        type=None,
        updated_date_utc=None,
        source_transaction_type_code=None,
        validation_errors=None,
    ):  # noqa: E501
        """LinkedTransaction - a model defined in OpenAPI"""  # noqa: E501

        self._source_transaction_id = None
        self._source_line_item_id = None
        self._contact_id = None
        self._target_transaction_id = None
        self._target_line_item_id = None
        self._linked_transaction_id = None
        self._status = None
        self._type = None
        self._updated_date_utc = None
        self._source_transaction_type_code = None
        self._validation_errors = None
        self.discriminator = None

        if source_transaction_id is not None:
            self.source_transaction_id = source_transaction_id
        if source_line_item_id is not None:
            self.source_line_item_id = source_line_item_id
        if contact_id is not None:
            self.contact_id = contact_id
        if target_transaction_id is not None:
            self.target_transaction_id = target_transaction_id
        if target_line_item_id is not None:
            self.target_line_item_id = target_line_item_id
        if linked_transaction_id is not None:
            self.linked_transaction_id = linked_transaction_id
        if status is not None:
            self.status = status
        if type is not None:
            self.type = type
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if source_transaction_type_code is not None:
            self.source_transaction_type_code = source_transaction_type_code
        if validation_errors is not None:
            self.validation_errors = validation_errors

    @property
    def source_transaction_id(self):
        """Gets the source_transaction_id of this LinkedTransaction.  # noqa: E501

        Filter by the SourceTransactionID. Get all the linked transactions created from a particular ACCPAY invoice  # noqa: E501

        :return: The source_transaction_id of this LinkedTransaction.  # noqa: E501
        :rtype: str
        """
        return self._source_transaction_id

    @source_transaction_id.setter
    def source_transaction_id(self, source_transaction_id):
        """Sets the source_transaction_id of this LinkedTransaction.

        Filter by the SourceTransactionID. Get all the linked transactions created from a particular ACCPAY invoice  # noqa: E501

        :param source_transaction_id: The source_transaction_id of this LinkedTransaction.  # noqa: E501
        :type: str
        """

        self._source_transaction_id = source_transaction_id

    @property
    def source_line_item_id(self):
        """Gets the source_line_item_id of this LinkedTransaction.  # noqa: E501

        The line item identifier from the source transaction.  # noqa: E501

        :return: The source_line_item_id of this LinkedTransaction.  # noqa: E501
        :rtype: str
        """
        return self._source_line_item_id

    @source_line_item_id.setter
    def source_line_item_id(self, source_line_item_id):
        """Sets the source_line_item_id of this LinkedTransaction.

        The line item identifier from the source transaction.  # noqa: E501

        :param source_line_item_id: The source_line_item_id of this LinkedTransaction.  # noqa: E501
        :type: str
        """

        self._source_line_item_id = source_line_item_id

    @property
    def contact_id(self):
        """Gets the contact_id of this LinkedTransaction.  # noqa: E501

        Filter by the combination of ContactID and Status. Get all the linked transactions that have been assigned to a particular customer and have a particular status e.g. GET /LinkedTransactions?ContactID=4bb34b03-3378-4bb2-a0ed-6345abf3224e&Status=APPROVED.  # noqa: E501

        :return: The contact_id of this LinkedTransaction.  # noqa: E501
        :rtype: str
        """
        return self._contact_id

    @contact_id.setter
    def contact_id(self, contact_id):
        """Sets the contact_id of this LinkedTransaction.

        Filter by the combination of ContactID and Status. Get all the linked transactions that have been assigned to a particular customer and have a particular status e.g. GET /LinkedTransactions?ContactID=4bb34b03-3378-4bb2-a0ed-6345abf3224e&Status=APPROVED.  # noqa: E501

        :param contact_id: The contact_id of this LinkedTransaction.  # noqa: E501
        :type: str
        """

        self._contact_id = contact_id

    @property
    def target_transaction_id(self):
        """Gets the target_transaction_id of this LinkedTransaction.  # noqa: E501

        Filter by the TargetTransactionID. Get all the linked transactions  allocated to a particular ACCREC invoice  # noqa: E501

        :return: The target_transaction_id of this LinkedTransaction.  # noqa: E501
        :rtype: str
        """
        return self._target_transaction_id

    @target_transaction_id.setter
    def target_transaction_id(self, target_transaction_id):
        """Sets the target_transaction_id of this LinkedTransaction.

        Filter by the TargetTransactionID. Get all the linked transactions  allocated to a particular ACCREC invoice  # noqa: E501

        :param target_transaction_id: The target_transaction_id of this LinkedTransaction.  # noqa: E501
        :type: str
        """

        self._target_transaction_id = target_transaction_id

    @property
    def target_line_item_id(self):
        """Gets the target_line_item_id of this LinkedTransaction.  # noqa: E501

        The line item identifier from the target transaction. It is possible  to link multiple billable expenses to the same TargetLineItemID.  # noqa: E501

        :return: The target_line_item_id of this LinkedTransaction.  # noqa: E501
        :rtype: str
        """
        return self._target_line_item_id

    @target_line_item_id.setter
    def target_line_item_id(self, target_line_item_id):
        """Sets the target_line_item_id of this LinkedTransaction.

        The line item identifier from the target transaction. It is possible  to link multiple billable expenses to the same TargetLineItemID.  # noqa: E501

        :param target_line_item_id: The target_line_item_id of this LinkedTransaction.  # noqa: E501
        :type: str
        """

        self._target_line_item_id = target_line_item_id

    @property
    def linked_transaction_id(self):
        """Gets the linked_transaction_id of this LinkedTransaction.  # noqa: E501

        The Xero identifier for an Linked Transaction e.g./LinkedTransactions/297c2dc5-cc47-4afd-8ec8-74990b8761e9  # noqa: E501

        :return: The linked_transaction_id of this LinkedTransaction.  # noqa: E501
        :rtype: str
        """
        return self._linked_transaction_id

    @linked_transaction_id.setter
    def linked_transaction_id(self, linked_transaction_id):
        """Sets the linked_transaction_id of this LinkedTransaction.

        The Xero identifier for an Linked Transaction e.g./LinkedTransactions/297c2dc5-cc47-4afd-8ec8-74990b8761e9  # noqa: E501

        :param linked_transaction_id: The linked_transaction_id of this LinkedTransaction.  # noqa: E501
        :type: str
        """

        self._linked_transaction_id = linked_transaction_id

    @property
    def status(self):
        """Gets the status of this LinkedTransaction.  # noqa: E501

        Filter by the combination of ContactID and Status. Get all the linked transactions that have been assigned to a particular customer and have a particular status e.g. GET /LinkedTransactions?ContactID=4bb34b03-3378-4bb2-a0ed-6345abf3224e&Status=APPROVED.  # noqa: E501

        :return: The status of this LinkedTransaction.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this LinkedTransaction.

        Filter by the combination of ContactID and Status. Get all the linked transactions that have been assigned to a particular customer and have a particular status e.g. GET /LinkedTransactions?ContactID=4bb34b03-3378-4bb2-a0ed-6345abf3224e&Status=APPROVED.  # noqa: E501

        :param status: The status of this LinkedTransaction.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "APPROVED",
            "DRAFT",
            "ONDRAFT",
            "BILLED",
            "VOIDED",
            "None",
        ]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status

    @property
    def type(self):
        """Gets the type of this LinkedTransaction.  # noqa: E501

        This will always be BILLABLEEXPENSE. More types may be added in future.  # noqa: E501

        :return: The type of this LinkedTransaction.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this LinkedTransaction.

        This will always be BILLABLEEXPENSE. More types may be added in future.  # noqa: E501

        :param type: The type of this LinkedTransaction.  # noqa: E501
        :type: str
        """
        allowed_values = ["BILLABLEEXPENSE", "None"]  # noqa: E501

        if type:
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                        type, allowed_values
                    )
                )

        self._type = type

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this LinkedTransaction.  # noqa: E501

        The last modified date in UTC format  # noqa: E501

        :return: The updated_date_utc of this LinkedTransaction.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this LinkedTransaction.

        The last modified date in UTC format  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this LinkedTransaction.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def source_transaction_type_code(self):
        """Gets the source_transaction_type_code of this LinkedTransaction.  # noqa: E501

        The Type of the source tranasction. This will be ACCPAY if the linked transaction was created from an invoice and SPEND if it was created from a bank transaction.  # noqa: E501

        :return: The source_transaction_type_code of this LinkedTransaction.  # noqa: E501
        :rtype: str
        """
        return self._source_transaction_type_code

    @source_transaction_type_code.setter
    def source_transaction_type_code(self, source_transaction_type_code):
        """Sets the source_transaction_type_code of this LinkedTransaction.

        The Type of the source tranasction. This will be ACCPAY if the linked transaction was created from an invoice and SPEND if it was created from a bank transaction.  # noqa: E501

        :param source_transaction_type_code: The source_transaction_type_code of this LinkedTransaction.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACCPAY", "SPEND", "None"]  # noqa: E501

        if source_transaction_type_code:
            if source_transaction_type_code not in allowed_values:
                raise ValueError(
                    "Invalid value for `source_transaction_type_code` ({0}), must be one of {1}".format(  # noqa: E501
                        source_transaction_type_code, allowed_values
                    )
                )

        self._source_transaction_type_code = source_transaction_type_code

    @property
    def validation_errors(self):
        """Gets the validation_errors of this LinkedTransaction.  # noqa: E501

        Displays array of validation error messages from the API  # noqa: E501

        :return: The validation_errors of this LinkedTransaction.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this LinkedTransaction.

        Displays array of validation error messages from the API  # noqa: E501

        :param validation_errors: The validation_errors of this LinkedTransaction.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors



# coding: utf-8

# flake8: noqa
"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


# import models into model package
from xero_python.accounting.models.account import Account
from xero_python.accounting.models.account_type import AccountType
from xero_python.accounting.models.accounts import Accounts
from xero_python.accounting.models.accounts_payable import AccountsPayable
from xero_python.accounting.models.accounts_receivable import AccountsReceivable
from xero_python.accounting.models.action import Action
from xero_python.accounting.models.actions import Actions
from xero_python.accounting.models.address import Address
from xero_python.accounting.models.address_for_organisation import (
    AddressForOrganisation,
)
from xero_python.accounting.models.allocation import Allocation
from xero_python.accounting.models.allocations import Allocations
from xero_python.accounting.models.attachment import Attachment
from xero_python.accounting.models.attachments import Attachments
from xero_python.accounting.models.balance_details import BalanceDetails
from xero_python.accounting.models.balances import Balances
from xero_python.accounting.models.bank_transaction import BankTransaction
from xero_python.accounting.models.bank_transactions import BankTransactions
from xero_python.accounting.models.bank_transfer import BankTransfer
from xero_python.accounting.models.bank_transfers import BankTransfers
from xero_python.accounting.models.batch_payment import BatchPayment
from xero_python.accounting.models.batch_payment_details import BatchPaymentDetails
from xero_python.accounting.models.batch_payments import BatchPayments
from xero_python.accounting.models.bill import Bill
from xero_python.accounting.models.branding_theme import BrandingTheme
from xero_python.accounting.models.branding_themes import BrandingThemes
from xero_python.accounting.models.cis_org_setting import CISOrgSetting
from xero_python.accounting.models.cis_org_settings import CISOrgSettings
from xero_python.accounting.models.cis_setting import CISSetting
from xero_python.accounting.models.cis_settings import CISSettings
from xero_python.accounting.models.contact import Contact
from xero_python.accounting.models.contact_group import ContactGroup
from xero_python.accounting.models.contact_groups import ContactGroups
from xero_python.accounting.models.contact_person import ContactPerson
from xero_python.accounting.models.contacts import Contacts
from xero_python.accounting.models.conversion_balances import ConversionBalances
from xero_python.accounting.models.conversion_date import ConversionDate
from xero_python.accounting.models.country_code import CountryCode
from xero_python.accounting.models.credit_note import CreditNote
from xero_python.accounting.models.credit_notes import CreditNotes
from xero_python.accounting.models.currencies import Currencies
from xero_python.accounting.models.currency import Currency
from xero_python.accounting.models.currency_code import CurrencyCode
from xero_python.accounting.models.element import Element
from xero_python.accounting.models.employee import Employee
from xero_python.accounting.models.employees import Employees
from xero_python.accounting.models.error import Error
from xero_python.accounting.models.expense_claim import ExpenseClaim
from xero_python.accounting.models.expense_claims import ExpenseClaims
from xero_python.accounting.models.external_link import ExternalLink
from xero_python.accounting.models.history_record import HistoryRecord
from xero_python.accounting.models.history_records import HistoryRecords
from xero_python.accounting.models.import_summary import ImportSummary
from xero_python.accounting.models.import_summary_accounts import ImportSummaryAccounts
from xero_python.accounting.models.import_summary_object import ImportSummaryObject
from xero_python.accounting.models.import_summary_organisation import (
    ImportSummaryOrganisation,
)
from xero_python.accounting.models.invoice import Invoice
from xero_python.accounting.models.invoice_reminder import InvoiceReminder
from xero_python.accounting.models.invoice_reminders import InvoiceReminders
from xero_python.accounting.models.invoices import Invoices
from xero_python.accounting.models.item import Item
from xero_python.accounting.models.items import Items
from xero_python.accounting.models.journal import Journal
from xero_python.accounting.models.journal_line import JournalLine
from xero_python.accounting.models.journals import Journals
from xero_python.accounting.models.line_amount_types import LineAmountTypes
from xero_python.accounting.models.line_item import LineItem
from xero_python.accounting.models.line_item_tracking import LineItemTracking
from xero_python.accounting.models.linked_transaction import LinkedTransaction
from xero_python.accounting.models.linked_transactions import LinkedTransactions
from xero_python.accounting.models.manual_journal import ManualJournal
from xero_python.accounting.models.manual_journal_line import ManualJournalLine
from xero_python.accounting.models.manual_journals import ManualJournals
from xero_python.accounting.models.online_invoice import OnlineInvoice
from xero_python.accounting.models.online_invoices import OnlineInvoices
from xero_python.accounting.models.organisation import Organisation
from xero_python.accounting.models.organisations import Organisations
from xero_python.accounting.models.overpayment import Overpayment
from xero_python.accounting.models.overpayments import Overpayments
from xero_python.accounting.models.payment import Payment
from xero_python.accounting.models.payment_delete import PaymentDelete
from xero_python.accounting.models.payment_service import PaymentService
from xero_python.accounting.models.payment_services import PaymentServices
from xero_python.accounting.models.payment_term import PaymentTerm
from xero_python.accounting.models.payment_term_type import PaymentTermType
from xero_python.accounting.models.payments import Payments
from xero_python.accounting.models.phone import Phone
from xero_python.accounting.models.prepayment import Prepayment
from xero_python.accounting.models.prepayments import Prepayments
from xero_python.accounting.models.purchase import Purchase
from xero_python.accounting.models.purchase_order import PurchaseOrder
from xero_python.accounting.models.purchase_orders import PurchaseOrders
from xero_python.accounting.models.quote import Quote
from xero_python.accounting.models.quote_line_amount_types import QuoteLineAmountTypes
from xero_python.accounting.models.quote_status_codes import QuoteStatusCodes
from xero_python.accounting.models.quotes import Quotes
from xero_python.accounting.models.receipt import Receipt
from xero_python.accounting.models.receipts import Receipts
from xero_python.accounting.models.repeating_invoice import RepeatingInvoice
from xero_python.accounting.models.repeating_invoices import RepeatingInvoices
from xero_python.accounting.models.report import Report
from xero_python.accounting.models.report_attribute import ReportAttribute
from xero_python.accounting.models.report_cell import ReportCell
from xero_python.accounting.models.report_fields import ReportFields
from xero_python.accounting.models.report_row import ReportRow
from xero_python.accounting.models.report_rows import ReportRows
from xero_python.accounting.models.report_with_row import ReportWithRow
from xero_python.accounting.models.report_with_rows import ReportWithRows
from xero_python.accounting.models.reports import Reports
from xero_python.accounting.models.request_empty import RequestEmpty
from xero_python.accounting.models.row_type import RowType
from xero_python.accounting.models.sales_tracking_category import SalesTrackingCategory
from xero_python.accounting.models.schedule import Schedule
from xero_python.accounting.models.setup import Setup
from xero_python.accounting.models.tax_component import TaxComponent
from xero_python.accounting.models.tax_rate import TaxRate
from xero_python.accounting.models.tax_rates import TaxRates
from xero_python.accounting.models.tax_type import TaxType
from xero_python.accounting.models.ten_ninety_nine_contact import TenNinetyNineContact
from xero_python.accounting.models.time_zone import TimeZone
from xero_python.accounting.models.tracking_categories import TrackingCategories
from xero_python.accounting.models.tracking_category import TrackingCategory
from xero_python.accounting.models.tracking_option import TrackingOption
from xero_python.accounting.models.tracking_options import TrackingOptions
from xero_python.accounting.models.user import User
from xero_python.accounting.models.users import Users
from xero_python.accounting.models.validation_error import ValidationError



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Action(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"name": "str", "status": "str"}

    attribute_map = {"name": "Name", "status": "Status"}

    def __init__(self, name=None, status=None):  # noqa: E501
        """Action - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._status = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if status is not None:
            self.status = status

    @property
    def name(self):
        """Gets the name of this Action.  # noqa: E501

        Name of the actions for this organisation  # noqa: E501

        :return: The name of this Action.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Action.

        Name of the actions for this organisation  # noqa: E501

        :param name: The name of this Action.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def status(self):
        """Gets the status of this Action.  # noqa: E501

        Status of the action for this organisation  # noqa: E501

        :return: The status of this Action.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Action.

        Status of the action for this organisation  # noqa: E501

        :param status: The status of this Action.  # noqa: E501
        :type: str
        """
        allowed_values = ["ALLOWED", "NOT-ALLOWED", "None"]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class TrackingCategory(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "employee_groups_tracking_category_id": "str",
        "timesheet_tracking_category_id": "str",
    }

    attribute_map = {
        "employee_groups_tracking_category_id": "employeeGroupsTrackingCategoryID",
        "timesheet_tracking_category_id": "timesheetTrackingCategoryID",
    }

    def __init__(
        self,
        employee_groups_tracking_category_id=None,
        timesheet_tracking_category_id=None,
    ):  # noqa: E501
        """TrackingCategory - a model defined in OpenAPI"""  # noqa: E501

        self._employee_groups_tracking_category_id = None
        self._timesheet_tracking_category_id = None
        self.discriminator = None

        if employee_groups_tracking_category_id is not None:
            self.employee_groups_tracking_category_id = (
                employee_groups_tracking_category_id
            )
        if timesheet_tracking_category_id is not None:
            self.timesheet_tracking_category_id = timesheet_tracking_category_id

    @property
    def employee_groups_tracking_category_id(self):
        """Gets the employee_groups_tracking_category_id of this TrackingCategory.  # noqa: E501

        The Xero identifier for Employee groups tracking category.  # noqa: E501

        :return: The employee_groups_tracking_category_id of this TrackingCategory.  # noqa: E501
        :rtype: str
        """
        return self._employee_groups_tracking_category_id

    @employee_groups_tracking_category_id.setter
    def employee_groups_tracking_category_id(
        self, employee_groups_tracking_category_id
    ):
        """Sets the employee_groups_tracking_category_id of this TrackingCategory.

        The Xero identifier for Employee groups tracking category.  # noqa: E501

        :param employee_groups_tracking_category_id: The employee_groups_tracking_category_id of this TrackingCategory.  # noqa: E501
        :type: str
        """

        self._employee_groups_tracking_category_id = (
            employee_groups_tracking_category_id
        )

    @property
    def timesheet_tracking_category_id(self):
        """Gets the timesheet_tracking_category_id of this TrackingCategory.  # noqa: E501

        The Xero identifier for Timesheet tracking category.  # noqa: E501

        :return: The timesheet_tracking_category_id of this TrackingCategory.  # noqa: E501
        :rtype: str
        """
        return self._timesheet_tracking_category_id

    @timesheet_tracking_category_id.setter
    def timesheet_tracking_category_id(self, timesheet_tracking_category_id):
        """Sets the timesheet_tracking_category_id of this TrackingCategory.

        The Xero identifier for Timesheet tracking category.  # noqa: E501

        :param timesheet_tracking_category_id: The timesheet_tracking_category_id of this TrackingCategory.  # noqa: E501
        :type: str
        """

        self._timesheet_tracking_category_id = timesheet_tracking_category_id



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class OpeningBalances(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "opening_balance_date": "date[ms-format]",
        "tax": "str",
        "earnings_lines": "list[EarningsLine]",
        "deduction_lines": "list[DeductionLine]",
        "super_lines": "list[SuperLine]",
        "reimbursement_lines": "list[ReimbursementLine]",
        "leave_lines": "list[LeaveLine]",
    }

    attribute_map = {
        "opening_balance_date": "OpeningBalanceDate",
        "tax": "Tax",
        "earnings_lines": "EarningsLines",
        "deduction_lines": "DeductionLines",
        "super_lines": "SuperLines",
        "reimbursement_lines": "ReimbursementLines",
        "leave_lines": "LeaveLines",
    }

    def __init__(
        self,
        opening_balance_date=None,
        tax=None,
        earnings_lines=None,
        deduction_lines=None,
        super_lines=None,
        reimbursement_lines=None,
        leave_lines=None,
    ):  # noqa: E501
        """OpeningBalances - a model defined in OpenAPI"""  # noqa: E501

        self._opening_balance_date = None
        self._tax = None
        self._earnings_lines = None
        self._deduction_lines = None
        self._super_lines = None
        self._reimbursement_lines = None
        self._leave_lines = None
        self.discriminator = None

        if opening_balance_date is not None:
            self.opening_balance_date = opening_balance_date
        if tax is not None:
            self.tax = tax
        if earnings_lines is not None:
            self.earnings_lines = earnings_lines
        if deduction_lines is not None:
            self.deduction_lines = deduction_lines
        if super_lines is not None:
            self.super_lines = super_lines
        if reimbursement_lines is not None:
            self.reimbursement_lines = reimbursement_lines
        if leave_lines is not None:
            self.leave_lines = leave_lines

    @property
    def opening_balance_date(self):
        """Gets the opening_balance_date of this OpeningBalances.  # noqa: E501

        Opening Balance Date. (YYYY-MM-DD)  # noqa: E501

        :return: The opening_balance_date of this OpeningBalances.  # noqa: E501
        :rtype: date
        """
        return self._opening_balance_date

    @opening_balance_date.setter
    def opening_balance_date(self, opening_balance_date):
        """Sets the opening_balance_date of this OpeningBalances.

        Opening Balance Date. (YYYY-MM-DD)  # noqa: E501

        :param opening_balance_date: The opening_balance_date of this OpeningBalances.  # noqa: E501
        :type: date
        """

        self._opening_balance_date = opening_balance_date

    @property
    def tax(self):
        """Gets the tax of this OpeningBalances.  # noqa: E501

        Opening Balance tax  # noqa: E501

        :return: The tax of this OpeningBalances.  # noqa: E501
        :rtype: str
        """
        return self._tax

    @tax.setter
    def tax(self, tax):
        """Sets the tax of this OpeningBalances.

        Opening Balance tax  # noqa: E501

        :param tax: The tax of this OpeningBalances.  # noqa: E501
        :type: str
        """

        self._tax = tax

    @property
    def earnings_lines(self):
        """Gets the earnings_lines of this OpeningBalances.  # noqa: E501


        :return: The earnings_lines of this OpeningBalances.  # noqa: E501
        :rtype: list[EarningsLine]
        """
        return self._earnings_lines

    @earnings_lines.setter
    def earnings_lines(self, earnings_lines):
        """Sets the earnings_lines of this OpeningBalances.


        :param earnings_lines: The earnings_lines of this OpeningBalances.  # noqa: E501
        :type: list[EarningsLine]
        """

        self._earnings_lines = earnings_lines

    @property
    def deduction_lines(self):
        """Gets the deduction_lines of this OpeningBalances.  # noqa: E501


        :return: The deduction_lines of this OpeningBalances.  # noqa: E501
        :rtype: list[DeductionLine]
        """
        return self._deduction_lines

    @deduction_lines.setter
    def deduction_lines(self, deduction_lines):
        """Sets the deduction_lines of this OpeningBalances.


        :param deduction_lines: The deduction_lines of this OpeningBalances.  # noqa: E501
        :type: list[DeductionLine]
        """

        self._deduction_lines = deduction_lines

    @property
    def super_lines(self):
        """Gets the super_lines of this OpeningBalances.  # noqa: E501


        :return: The super_lines of this OpeningBalances.  # noqa: E501
        :rtype: list[SuperLine]
        """
        return self._super_lines

    @super_lines.setter
    def super_lines(self, super_lines):
        """Sets the super_lines of this OpeningBalances.


        :param super_lines: The super_lines of this OpeningBalances.  # noqa: E501
        :type: list[SuperLine]
        """

        self._super_lines = super_lines

    @property
    def reimbursement_lines(self):
        """Gets the reimbursement_lines of this OpeningBalances.  # noqa: E501


        :return: The reimbursement_lines of this OpeningBalances.  # noqa: E501
        :rtype: list[ReimbursementLine]
        """
        return self._reimbursement_lines

    @reimbursement_lines.setter
    def reimbursement_lines(self, reimbursement_lines):
        """Sets the reimbursement_lines of this OpeningBalances.


        :param reimbursement_lines: The reimbursement_lines of this OpeningBalances.  # noqa: E501
        :type: list[ReimbursementLine]
        """

        self._reimbursement_lines = reimbursement_lines

    @property
    def leave_lines(self):
        """Gets the leave_lines of this OpeningBalances.  # noqa: E501


        :return: The leave_lines of this OpeningBalances.  # noqa: E501
        :rtype: list[LeaveLine]
        """
        return self._leave_lines

    @leave_lines.setter
    def leave_lines(self, leave_lines):
        """Sets the leave_lines of this OpeningBalances.


        :param leave_lines: The leave_lines of this OpeningBalances.  # noqa: E501
        :type: list[LeaveLine]
        """

        self._leave_lines = leave_lines



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class PayItem(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "earnings_rates": "list[EarningsRate]",
        "deduction_types": "list[DeductionType]",
        "leave_types": "list[LeaveType]",
        "reimbursement_types": "list[ReimbursementType]",
    }

    attribute_map = {
        "earnings_rates": "EarningsRates",
        "deduction_types": "DeductionTypes",
        "leave_types": "LeaveTypes",
        "reimbursement_types": "ReimbursementTypes",
    }

    def __init__(
        self,
        earnings_rates=None,
        deduction_types=None,
        leave_types=None,
        reimbursement_types=None,
    ):  # noqa: E501
        """PayItem - a model defined in OpenAPI"""  # noqa: E501

        self._earnings_rates = None
        self._deduction_types = None
        self._leave_types = None
        self._reimbursement_types = None
        self.discriminator = None

        if earnings_rates is not None:
            self.earnings_rates = earnings_rates
        if deduction_types is not None:
            self.deduction_types = deduction_types
        if leave_types is not None:
            self.leave_types = leave_types
        if reimbursement_types is not None:
            self.reimbursement_types = reimbursement_types

    @property
    def earnings_rates(self):
        """Gets the earnings_rates of this PayItem.  # noqa: E501


        :return: The earnings_rates of this PayItem.  # noqa: E501
        :rtype: list[EarningsRate]
        """
        return self._earnings_rates

    @earnings_rates.setter
    def earnings_rates(self, earnings_rates):
        """Sets the earnings_rates of this PayItem.


        :param earnings_rates: The earnings_rates of this PayItem.  # noqa: E501
        :type: list[EarningsRate]
        """

        self._earnings_rates = earnings_rates

    @property
    def deduction_types(self):
        """Gets the deduction_types of this PayItem.  # noqa: E501


        :return: The deduction_types of this PayItem.  # noqa: E501
        :rtype: list[DeductionType]
        """
        return self._deduction_types

    @deduction_types.setter
    def deduction_types(self, deduction_types):
        """Sets the deduction_types of this PayItem.


        :param deduction_types: The deduction_types of this PayItem.  # noqa: E501
        :type: list[DeductionType]
        """

        self._deduction_types = deduction_types

    @property
    def leave_types(self):
        """Gets the leave_types of this PayItem.  # noqa: E501


        :return: The leave_types of this PayItem.  # noqa: E501
        :rtype: list[LeaveType]
        """
        return self._leave_types

    @leave_types.setter
    def leave_types(self, leave_types):
        """Sets the leave_types of this PayItem.


        :param leave_types: The leave_types of this PayItem.  # noqa: E501
        :type: list[LeaveType]
        """

        self._leave_types = leave_types

    @property
    def reimbursement_types(self):
        """Gets the reimbursement_types of this PayItem.  # noqa: E501


        :return: The reimbursement_types of this PayItem.  # noqa: E501
        :rtype: list[ReimbursementType]
        """
        return self._reimbursement_types

    @reimbursement_types.setter
    def reimbursement_types(self, reimbursement_types):
        """Sets the reimbursement_types of this PayItem.


        :param reimbursement_types: The reimbursement_types of this PayItem.  # noqa: E501
        :type: list[ReimbursementType]
        """

        self._reimbursement_types = reimbursement_types



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class BatchPayment(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "account": "Account",
        "reference": "str",
        "particulars": "str",
        "code": "str",
        "details": "str",
        "narrative": "str",
        "batch_payment_id": "str",
        "date_string": "str",
        "date": "date[ms-format]",
        "amount": "float",
        "payments": "list[Payment]",
        "type": "str",
        "status": "str",
        "total_amount": "str",
        "updated_date_utc": "datetime[ms-format]",
        "is_reconciled": "str",
        "validation_errors": "list[ValidationError]",
    }

    attribute_map = {
        "account": "Account",
        "reference": "Reference",
        "particulars": "Particulars",
        "code": "Code",
        "details": "Details",
        "narrative": "Narrative",
        "batch_payment_id": "BatchPaymentID",
        "date_string": "DateString",
        "date": "Date",
        "amount": "Amount",
        "payments": "Payments",
        "type": "Type",
        "status": "Status",
        "total_amount": "TotalAmount",
        "updated_date_utc": "UpdatedDateUTC",
        "is_reconciled": "IsReconciled",
        "validation_errors": "ValidationErrors",
    }

    def __init__(
        self,
        account=None,
        reference=None,
        particulars=None,
        code=None,
        details=None,
        narrative=None,
        batch_payment_id=None,
        date_string=None,
        date=None,
        amount=None,
        payments=None,
        type=None,
        status=None,
        total_amount=None,
        updated_date_utc=None,
        is_reconciled=None,
        validation_errors=None,
    ):  # noqa: E501
        """BatchPayment - a model defined in OpenAPI"""  # noqa: E501

        self._account = None
        self._reference = None
        self._particulars = None
        self._code = None
        self._details = None
        self._narrative = None
        self._batch_payment_id = None
        self._date_string = None
        self._date = None
        self._amount = None
        self._payments = None
        self._type = None
        self._status = None
        self._total_amount = None
        self._updated_date_utc = None
        self._is_reconciled = None
        self._validation_errors = None
        self.discriminator = None

        if account is not None:
            self.account = account
        if reference is not None:
            self.reference = reference
        if particulars is not None:
            self.particulars = particulars
        if code is not None:
            self.code = code
        if details is not None:
            self.details = details
        if narrative is not None:
            self.narrative = narrative
        if batch_payment_id is not None:
            self.batch_payment_id = batch_payment_id
        if date_string is not None:
            self.date_string = date_string
        if date is not None:
            self.date = date
        if amount is not None:
            self.amount = amount
        if payments is not None:
            self.payments = payments
        if type is not None:
            self.type = type
        if status is not None:
            self.status = status
        if total_amount is not None:
            self.total_amount = total_amount
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if is_reconciled is not None:
            self.is_reconciled = is_reconciled
        if validation_errors is not None:
            self.validation_errors = validation_errors

    @property
    def account(self):
        """Gets the account of this BatchPayment.  # noqa: E501


        :return: The account of this BatchPayment.  # noqa: E501
        :rtype: Account
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this BatchPayment.


        :param account: The account of this BatchPayment.  # noqa: E501
        :type: Account
        """

        self._account = account

    @property
    def reference(self):
        """Gets the reference of this BatchPayment.  # noqa: E501

        (NZ Only) Optional references for the batch payment transaction. It will also show with the batch payment transaction in the bank reconciliation Find & Match screen. Depending on your individual bank, the detail may also show on the bank statement you import into Xero.  # noqa: E501

        :return: The reference of this BatchPayment.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this BatchPayment.

        (NZ Only) Optional references for the batch payment transaction. It will also show with the batch payment transaction in the bank reconciliation Find & Match screen. Depending on your individual bank, the detail may also show on the bank statement you import into Xero.  # noqa: E501

        :param reference: The reference of this BatchPayment.  # noqa: E501
        :type: str
        """
        if reference is not None and len(reference) > 255:
            raise ValueError(
                "Invalid value for `reference`, "
                "length must be less than or equal to `255`"
            )  # noqa: E501

        self._reference = reference

    @property
    def particulars(self):
        """Gets the particulars of this BatchPayment.  # noqa: E501

        (NZ Only) Optional references for the batch payment transaction. It will also show with the batch payment transaction in the bank reconciliation Find & Match screen. Depending on your individual bank, the detail may also show on the bank statement you import into Xero.  # noqa: E501

        :return: The particulars of this BatchPayment.  # noqa: E501
        :rtype: str
        """
        return self._particulars

    @particulars.setter
    def particulars(self, particulars):
        """Sets the particulars of this BatchPayment.

        (NZ Only) Optional references for the batch payment transaction. It will also show with the batch payment transaction in the bank reconciliation Find & Match screen. Depending on your individual bank, the detail may also show on the bank statement you import into Xero.  # noqa: E501

        :param particulars: The particulars of this BatchPayment.  # noqa: E501
        :type: str
        """
        if particulars is not None and len(particulars) > 12:
            raise ValueError(
                "Invalid value for `particulars`, "
                "length must be less than or equal to `12`"
            )  # noqa: E501

        self._particulars = particulars

    @property
    def code(self):
        """Gets the code of this BatchPayment.  # noqa: E501

        (NZ Only) Optional references for the batch payment transaction. It will also show with the batch payment transaction in the bank reconciliation Find & Match screen. Depending on your individual bank, the detail may also show on the bank statement you import into Xero.  # noqa: E501

        :return: The code of this BatchPayment.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this BatchPayment.

        (NZ Only) Optional references for the batch payment transaction. It will also show with the batch payment transaction in the bank reconciliation Find & Match screen. Depending on your individual bank, the detail may also show on the bank statement you import into Xero.  # noqa: E501

        :param code: The code of this BatchPayment.  # noqa: E501
        :type: str
        """
        if code is not None and len(code) > 12:
            raise ValueError(
                "Invalid value for `code`, " "length must be less than or equal to `12`"
            )  # noqa: E501

        self._code = code

    @property
    def details(self):
        """Gets the details of this BatchPayment.  # noqa: E501

        (Non-NZ Only) These details are sent to the org’s bank as a reference for the batch payment transaction. They will also show with the batch payment transaction in the bank reconciliation Find & Match screen. Depending on your individual bank, the detail may also show on the bank statement imported into Xero. Maximum field length = 18  # noqa: E501

        :return: The details of this BatchPayment.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this BatchPayment.

        (Non-NZ Only) These details are sent to the org’s bank as a reference for the batch payment transaction. They will also show with the batch payment transaction in the bank reconciliation Find & Match screen. Depending on your individual bank, the detail may also show on the bank statement imported into Xero. Maximum field length = 18  # noqa: E501

        :param details: The details of this BatchPayment.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def narrative(self):
        """Gets the narrative of this BatchPayment.  # noqa: E501

        (UK Only) Only shows on the statement line in Xero. Max length =18  # noqa: E501

        :return: The narrative of this BatchPayment.  # noqa: E501
        :rtype: str
        """
        return self._narrative

    @narrative.setter
    def narrative(self, narrative):
        """Sets the narrative of this BatchPayment.

        (UK Only) Only shows on the statement line in Xero. Max length =18  # noqa: E501

        :param narrative: The narrative of this BatchPayment.  # noqa: E501
        :type: str
        """
        if narrative is not None and len(narrative) > 18:
            raise ValueError(
                "Invalid value for `narrative`, "
                "length must be less than or equal to `18`"
            )  # noqa: E501

        self._narrative = narrative

    @property
    def batch_payment_id(self):
        """Gets the batch_payment_id of this BatchPayment.  # noqa: E501

        The Xero generated unique identifier for the bank transaction (read-only)  # noqa: E501

        :return: The batch_payment_id of this BatchPayment.  # noqa: E501
        :rtype: str
        """
        return self._batch_payment_id

    @batch_payment_id.setter
    def batch_payment_id(self, batch_payment_id):
        """Sets the batch_payment_id of this BatchPayment.

        The Xero generated unique identifier for the bank transaction (read-only)  # noqa: E501

        :param batch_payment_id: The batch_payment_id of this BatchPayment.  # noqa: E501
        :type: str
        """

        self._batch_payment_id = batch_payment_id

    @property
    def date_string(self):
        """Gets the date_string of this BatchPayment.  # noqa: E501

        Date the payment is being made (YYYY-MM-DD) e.g. 2009-09-06  # noqa: E501

        :return: The date_string of this BatchPayment.  # noqa: E501
        :rtype: str
        """
        return self._date_string

    @date_string.setter
    def date_string(self, date_string):
        """Sets the date_string of this BatchPayment.

        Date the payment is being made (YYYY-MM-DD) e.g. 2009-09-06  # noqa: E501

        :param date_string: The date_string of this BatchPayment.  # noqa: E501
        :type: str
        """

        self._date_string = date_string

    @property
    def date(self):
        """Gets the date of this BatchPayment.  # noqa: E501

        Date the payment is being made (YYYY-MM-DD) e.g. 2009-09-06  # noqa: E501

        :return: The date of this BatchPayment.  # noqa: E501
        :rtype: date
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this BatchPayment.

        Date the payment is being made (YYYY-MM-DD) e.g. 2009-09-06  # noqa: E501

        :param date: The date of this BatchPayment.  # noqa: E501
        :type: date
        """

        self._date = date

    @property
    def amount(self):
        """Gets the amount of this BatchPayment.  # noqa: E501

        The amount of the payment. Must be less than or equal to the outstanding amount owing on the invoice e.g. 200.00  # noqa: E501

        :return: The amount of this BatchPayment.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this BatchPayment.

        The amount of the payment. Must be less than or equal to the outstanding amount owing on the invoice e.g. 200.00  # noqa: E501

        :param amount: The amount of this BatchPayment.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def payments(self):
        """Gets the payments of this BatchPayment.  # noqa: E501

        An array of payments  # noqa: E501

        :return: The payments of this BatchPayment.  # noqa: E501
        :rtype: list[Payment]
        """
        return self._payments

    @payments.setter
    def payments(self, payments):
        """Sets the payments of this BatchPayment.

        An array of payments  # noqa: E501

        :param payments: The payments of this BatchPayment.  # noqa: E501
        :type: list[Payment]
        """

        self._payments = payments

    @property
    def type(self):
        """Gets the type of this BatchPayment.  # noqa: E501

        PAYBATCH for bill payments or RECBATCH for sales invoice payments (read-only)  # noqa: E501

        :return: The type of this BatchPayment.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BatchPayment.

        PAYBATCH for bill payments or RECBATCH for sales invoice payments (read-only)  # noqa: E501

        :param type: The type of this BatchPayment.  # noqa: E501
        :type: str
        """
        allowed_values = ["PAYBATCH", "RECBATCH", "None"]  # noqa: E501

        if type:
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                        type, allowed_values
                    )
                )

        self._type = type

    @property
    def status(self):
        """Gets the status of this BatchPayment.  # noqa: E501

        AUTHORISED or DELETED (read-only). New batch payments will have a status of AUTHORISED. It is not possible to delete batch payments via the API.  # noqa: E501

        :return: The status of this BatchPayment.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BatchPayment.

        AUTHORISED or DELETED (read-only). New batch payments will have a status of AUTHORISED. It is not possible to delete batch payments via the API.  # noqa: E501

        :param status: The status of this BatchPayment.  # noqa: E501
        :type: str
        """
        allowed_values = ["AUTHORISED", "DELETED", "None"]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status

    @property
    def total_amount(self):
        """Gets the total_amount of this BatchPayment.  # noqa: E501

        The total of the payments that make up the batch (read-only)  # noqa: E501

        :return: The total_amount of this BatchPayment.  # noqa: E501
        :rtype: str
        """
        return self._total_amount

    @total_amount.setter
    def total_amount(self, total_amount):
        """Sets the total_amount of this BatchPayment.

        The total of the payments that make up the batch (read-only)  # noqa: E501

        :param total_amount: The total_amount of this BatchPayment.  # noqa: E501
        :type: str
        """

        self._total_amount = total_amount

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this BatchPayment.  # noqa: E501

        UTC timestamp of last update to the payment  # noqa: E501

        :return: The updated_date_utc of this BatchPayment.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this BatchPayment.

        UTC timestamp of last update to the payment  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this BatchPayment.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def is_reconciled(self):
        """Gets the is_reconciled of this BatchPayment.  # noqa: E501

        Booelan that tells you if the batch payment has been reconciled (read-only)  # noqa: E501

        :return: The is_reconciled of this BatchPayment.  # noqa: E501
        :rtype: str
        """
        return self._is_reconciled

    @is_reconciled.setter
    def is_reconciled(self, is_reconciled):
        """Sets the is_reconciled of this BatchPayment.

        Booelan that tells you if the batch payment has been reconciled (read-only)  # noqa: E501

        :param is_reconciled: The is_reconciled of this BatchPayment.  # noqa: E501
        :type: str
        """

        self._is_reconciled = is_reconciled

    @property
    def validation_errors(self):
        """Gets the validation_errors of this BatchPayment.  # noqa: E501

        Displays array of validation error messages from the API  # noqa: E501

        :return: The validation_errors of this BatchPayment.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this BatchPayment.

        Displays array of validation error messages from the API  # noqa: E501

        :param validation_errors: The validation_errors of this BatchPayment.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Currency(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"code": "CurrencyCode", "description": "str"}

    attribute_map = {"code": "Code", "description": "Description"}

    def __init__(self, code=None, description=None):  # noqa: E501
        """Currency - a model defined in OpenAPI"""  # noqa: E501

        self._code = None
        self._description = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if description is not None:
            self.description = description

    @property
    def code(self):
        """Gets the code of this Currency.  # noqa: E501


        :return: The code of this Currency.  # noqa: E501
        :rtype: CurrencyCode
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this Currency.


        :param code: The code of this Currency.  # noqa: E501
        :type: CurrencyCode
        """

        self._code = code

    @property
    def description(self):
        """Gets the description of this Currency.  # noqa: E501

        Name of Currency  # noqa: E501

        :return: The description of this Currency.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Currency.

        Name of Currency  # noqa: E501

        :param description: The description of this Currency.  # noqa: E501
        :type: str
        """

        self._description = description
